-- ============================================================================
-- Project:	Deductive Database
-- Filename:	bench_db.sql
-- Purpose:	Database for Benchmark Runs
-- Last Change:	20.06.2018
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2016-2018 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ============================================================================
-- Delete Old Versions of the Tables:
-- ============================================================================

-- When this script is executed the first time,
-- these commands generate errors (because the tables/views do not exist).

DROP VIEW  DBS_RESULTS;
DROP VIEW  BACH_RESULTS;
DROP VIEW  BEST_OPT;
DROP VIEW  RUN_STATISTICS;

DROP TABLE BENCH_RUN;
DROP TABLE BENCH_INPUT;
DROP TABLE BENCH_IMPL;
DROP TABLE PROG_VER;
DROP TABLE PROGRAM;
DROP TABLE BENCHMARK;
DROP TABLE MACHINE;

-- ============================================================================
-- List of Machines on which Benchmarks are Executed:
-- ============================================================================

CREATE TABLE MACHINE(
	MACHINE     VARCHAR(20)  NOT NULL,
	SEQ_NO      NUMERIC(2)   NOT NULL,
	NUM_CPUS    NUMERIC(4)   NOT NULL,
	CPU         VARCHAR(60)  NOT NULL,
	CPU_CORES   NUMERIC(4)   NULL,
        CPU_THREADS NUMERIC(4)   NULL,
	GHZ         NUMERIC(5,2) NULL,
	ARCH        VARCHAR(20)  NULL,
	RAM         NUMERIC(8,3) NOT NULL,
	NUM_DISKS   NUMERIC(4)   NULL,
        DISK        VARCHAR(40)  NULL,
	SSD         CHAR(1)      NULL,
	OS          VARCHAR(40)  NULL,
	OS_CORE     VARCHAR(40)  NULL,
	CONSTRAINT MACHINE_PK
		PRIMARY KEY(MACHINE),
	CONSTRAINT MACHINE_KEY_SEQ
		UNIQUE (SEQ_NO),
	CONSTRAINT MACHINE_SEQ_NO_POSITIVE
		CHECK(SEQ_NO > 0),
	CONSTRAINT MACHINE_NUM_CPUS_POSITIVE
		CHECK(NUM_CPUS > 0),
	CONSTRAINT MACHINE_CPU_CORES_POSITIVE
		CHECK(CPU_CORES > 0),
	CONSTRAINT MACHINE_CPU_THREADS_POSITIVE
		CHECK(CPU_THREADS > 0),
	CONSTRAINT MACHINE_RAM_POSITIVE
		CHECK(RAM > 0),
	CONSTRAINT MACHINE_NUM_DISKS_POSITIVE
		CHECK(NUM_DISKS > 0),
	CONSTRAINT MACHINE_SSD_YN
		CHECK(SSD IN ('Y','N')));

INSERT INTO MACHINE VALUES(
	'bach', 1,
	1, 'Xeon Intel 2011 E5-1620v4 4/8x 3,5GHz', 4, 8, 3.5, 'x86_64',
	16,
	1, 'Samsung SSD 850 EVO 500GB', 'Y',
	'CentOS Linux release 7.4.1708 (Core)',
	'Linux 3.10.0-693.21.1.el7.x86_64 x86_64');

INSERT INTO MACHINE VALUES(
	'dbs1', 2,
	2, 'Intel(R) Xeon(R) CPU E5-2630 v4 @ 2.20GHz', 10, 20, 2.2, 'x86_64',
	64,
	NULL, NULL, NULL,
	'Debian GNU/Linux 8.10 (jessie)',
	'Linux 3.16.0-5-amd64 x86_64');

-- Note that the CORE might not be current. It changes with every update.
-- It was current when we started the benchmarks in May 2018.
-- It gives some impression of the machine and its operating system.

-- ============================================================================
-- List of Benchmarks:
-- ============================================================================


CREATE TABLE BENCHMARK(
	BENCH      VARCHAR(20)  NOT NULL,
	SEQ_NO     NUMERIC(2)   NOT NULL,
	HEADLINE   VARCHAR(80)  NOT NULL,
	CONSTRAINT BENCHMARK_SEQ_NONNEGATIVE
		CHECK(SEQ_NO >= 0),
	CONSTRAINT BENCHMARK_PK
		PRIMARY KEY (BENCH),
	CONSTRAINT BENCHMARK_KEY_SEQ
		UNIQUE (SEQ_NO));

INSERT INTO BENCHMARK VALUES (
	'dblp', 1,
	'DBLP Benchmark');

INSERT INTO BENCHMARK VALUES (
	'j1axy', 2,
	'The Join1 Benchmark, Query a(X,Y)');

INSERT INTO BENCHMARK VALUES (
	'j1axyd', 3,
	'The Join1 Benchmark (without duplicate elimination)');

INSERT INTO BENCHMARK VALUES (
	'tcff', 4,
	'Transitive Closure Benchmark without Query Bindings');

INSERT INTO BENCHMARK VALUES (
	'tcbf', 5,
	'Transitive Closure Benchmark with the First Argument Bound');

INSERT INTO BENCHMARK VALUES (
	'tcbfs', 6,
	'Transitive Closure Benchmark, first arg bound, with SLDMagic');

INSERT INTO BENCHMARK VALUES (
	'wine', 7,
	'Wine Ontology Benchmark');

INSERT INTO BENCHMARK VALUES (
	'loadd', 8,
	'Test of Loader for DBLP Data');

INSERT INTO BENCHMARK VALUES (
	'loadt', 9,
	'Test of Loader for Transitive Closure');

INSERT INTO BENCHMARK VALUES (
	'set1', 10,
	'Test of Set Insertion and Lookup (One Column)');

INSERT INTO BENCHMARK VALUES (
	'set2', 11,
	'Test of Set Insertion and Lookup (Two Columns)');

-- ============================================================================
-- List of Programs to be Tested/Compared:
-- ============================================================================

CREATE TABLE PROGRAM(
	PROG        VARCHAR(20)  NOT NULL,
	SEQ_NO      NUMERIC(2)   NOT NULL,
	FULL_NAME   VARCHAR(40)  NOT NULL,
	URL         VARCHAR(80)  NULL,
	REMARK      VARCHAR(800) NULL,
	CONSTRAINT PROGRAM_SEQ_NONNEGATIVE
		CHECK(SEQ_NO >= 0),
	CONSTRAINT PROGRAM_PK
		PRIMARY KEY (PROG),
	CONSTRAINT PROGRAM_KEY_SEQ
		UNIQUE (SEQ_NO));

INSERT INTO PROGRAM VALUES (
	'ydb', 1, 'Push (ydb)',
	'http://users.informatik.uni-halle.de/~brass/push/',
	NULL);

INSERT INTO PROGRAM VALUES (
	'bam', 2, 'Push (bam)',
	'http://users.informatik.uni-halle.de/~brass/push/',
	NULL);

INSERT INTO PROGRAM VALUES (
	'xsb', 3, 'XSB',
	'http://xsb.sourceforge.net/',
	NULL);

INSERT INTO PROGRAM VALUES (
	'yap', 4, 'YAProlog',
	'https://www.dcc.fc.up.pt/~vsc/Yap/',
	NULL);

INSERT INTO PROGRAM VALUES (
	'souffle', 5, 'Souffle',
	'http://souffle-lang.org/',
	NULL);

INSERT INTO PROGRAM VALUES (
	'dlv', 6, 'DLV',
	'http://www.dlvsystem.com/',
	NULL);

INSERT INTO PROGRAM VALUES (
	'mercury', 7, 'Melbourne Mercury',
	'http://www.mercurylang.org/',
	NULL);

INSERT INTO PROGRAM VALUES (
	'hsql', 8, 'HSQLDB',
	'http://hsqldb.org/',
	NULL);

INSERT INTO PROGRAM VALUES (
	'swipl', 9, 'SWI-Prolog',
	'http://www.swi-prolog.org/',
	NULL);

-- ============================================================================
-- Table for Installed Program Versions on Machines:
-- ============================================================================

-- This table lists program versions
-- that are or were installed on a test machine.
-- They are identified here by a number that is unique together with
-- the program name and the machine.
-- These three elements (Program, Version number, and machine)
-- are also encoded in the file names with the test results.
--
-- Note that we use a simple sequential number VER for the version in the key,
-- not the real version number (which can be an arbitrary string).
-- The real version number is available in column VER_NAME
-- and can be used for output.
--
-- I try to make sure that the same VER_NAME of a program gets the same VER
-- number even on different machines, but the database schema does not
-- require this.
-- It is possible that a VER_NAME corresponds to different VER numbers,
-- for instance, if a program is compiled with different compilers or
-- compiler settings. This would require a new VER number.
--
-- Only program versions that are listed here can appear in the test runs.
--
-- This table also define a current version of a program on a machine
-- (by STATUS='C').  Some views show only results for the current version.
-- It is also possible to define a previous version (STATUS='P') as reference,
-- if the result of a program update should be evaluated.
-- Finally, one can mark an alternative version (STATUS='A'),
-- e.g. compiled with a different compiler or compiler options,
-- which can also be used for comparison.
--
-- VER_ADDTEXT should be concatenated with VER_NAME
-- to get the full name of the version.
-- This table also permits to store additional information about a version.
-- For instance, XSB outputs configuration information when started.

CREATE TABLE PROG_VER (
	PROG        VARCHAR(20)  NOT NULL,
	VER         NUMERIC(4)   NOT NULL,
	MACHINE     VARCHAR(20)  NOT NULL,
	VER_NAME    VARCHAR(20)  NOT NULL,
	VER_ADDTEXT VARCHAR(80)  NOT NULL,
	VER_DATE    DATE         NULL,
	COMPILER    VARCHAR(80)  NOT NULL,
	STATUS      CHAR(1)      NOT NULL,
	REMARK      VARCHAR(800) NULL,
	CONSTRAINT PROG_VER_PK
		PRIMARY KEY (PROG, VER, MACHINE),
	CONSTRAINT PROG_VER_REF_PROGRAM
		FOREIGN KEY (PROG) REFERENCES PROGRAM,
	CONSTRAINT PROG_VER_REF_MACHINE
		FOREIGN KEY (MACHINE) REFERENCES MACHINE,
	CONSTRAINT PROG_VER_STATUS_VALID
		CHECK(STATUS IN ('C','P','A',' ')));

INSERT INTO PROG_VER VALUES (
	'ydb', 1, 'bach',
	'0.1', '', '2016-11-21',
	'gcc version 4.8.5 (-O2)',
	'C',
	NULL);

INSERT INTO PROG_VER VALUES (
	'ydb', 1, 'dbs1',
	'0.1', '', '2016-11-21',
	'gcc version 4.9.2 (-O2)',
	'C',
	NULL);

INSERT INTO PROG_VER VALUES (
	'bam', 1, 'bach',
	'0.1a', '', '2018-04-24',
	'gcc version 4.8.5 (-O2)',
	'C',
	NULL);

INSERT INTO PROG_VER VALUES (
	'bam', 1, 'dbs1',
	'0.1a', '', '2018-04-24',
	'gcc version 4.9.2 (-O2)',
	'C',
	NULL);

INSERT INTO PROG_VER VALUES (
	'xsb', 1, 'dbs1',
	'3.7.', ' (Clan MacGregor)', '2016-07-06',
	'',
	'C',
	'x86_64-unknown-linux-gnu 64 bits; ' ||
		'mode: optimal; engine: slg-wam; scheduling: local');

INSERT INTO PROG_VER VALUES (
	'xsb', 2, 'bach',
	'3.8.0', ' (Three-Buck Chuck)', '2017-10-28',
	'',
	'C',
	'x86_64-unknown-linux-gnu 64 bits; ' ||
		'mode: optimal; engine: slg-wam; scheduling: local');

INSERT INTO PROG_VER VALUES (
	'yap', 1, 'dbs1',
	'6.2.2', ' (x86_64-linux)', '2011-10-21',
	'',
	'C',
	NULL);

INSERT INTO PROG_VER VALUES (
	'yap', 2, 'bach',
	'6.3.3', ' (x86_64-linux)', '2013-01-20',
	'',
	'C',
	NULL);

INSERT INTO PROG_VER VALUES (
	'swipl', 1, 'dbs1',
	'7.7.15', ' (x86_64-linux)', '2018-06-01',
	'',
	'C',
	NULL);

-- ============================================================================
-- Table for Implementation Variants of Benchmarks:
-- ============================================================================

CREATE TABLE BENCH_IMPL(
	PROG        VARCHAR(20)  NOT NULL,
	BENCH       VARCHAR(20)  NOT NULL,
	IMPL        VARCHAR(20)  NOT NULL,
	DESCRIPTION VARCHAR(80)  NULL,
	CONSTRAINT BENCH_IMPL_PK
		PRIMARY KEY (PROG, BENCH, IMPL),
	CONSTRAINT BENCH_IMPL_REF_BENCHMARK
		FOREIGN KEY (BENCH) REFERENCES BENCHMARK,
	CONSTRAINT BENCH_IMPL_REF_PROGRAM
		FOREIGN KEY (PROG) REFERENCES PROGRAM);


-- ============================================================================
-- Benchmark Implementations for bam:
-- ============================================================================

-- ----------------------------------------------------------------------------
-- Join1 Implementations for bam:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'j1axy', '1',
	'Join1, a(X,Y) [V1: RelAttr, -goto, fullDupCh]');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'j1axy', '2',
	'Join1, a(X,Y) [V2: no goto, bitmap-dupcheck]');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'j1axy', '3',
	'Join1, a(X,Y) [V3: goto, bitmap-dupC, cursor]');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'j1axy', '4',
	'Join1, a(X,Y) [V4: functions, bitmap-dupC]');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'j1axy', '5',
	'Join1, a(X,Y) [V5: fun without args, bitmap]');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'j1axy', '6',
	'Join1, a(X,Y) [V6: Abstract Machine, bitmap]');

-- ----------------------------------------------------------------------------
-- Transitive Closure Implementations for bam (TCFF - Both Arguments Free):
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'tcff', '1',
	'tc(X,Y) [V1: RelLocalVar]');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'tcff', '2',
	'tc(X,Y) [V2: Cursor Interface, switch]');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'tcff', '3',
	'tc(X,Y) [V3: Seminaive Evaluation]');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'tcff', '4',
	'tc(X,Y) [V4: Functions]');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'tcff', '5',
	'tc(X,Y) [V5: Abstract Machine]');

-- ----------------------------------------------------------------------------
-- Data Loader Tests for bam:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'loadt', '1',
	'transitive closure data file (with handcrafted loader)');

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'loadt', '2',
	'transitive closure data file (with general loader)');

-- ----------------------------------------------------------------------------
-- Set Implementation Tests for bam (One Column):
-- ----------------------------------------------------------------------------


INSERT INTO BENCH_IMPL VALUES (
	'bam', 'set1', '1',
	'Set with 1 column, extendible Hash table');

-- ----------------------------------------------------------------------------
-- Set Implementation Tests for bam (Two Columns):
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'bam', 'set2', '1',
	'Set with 2 columns, extendible Hash table');

-- ============================================================================
-- Tests for XSB:
-- ============================================================================

-- ----------------------------------------------------------------------------
-- DBLP Tests for XSB:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'dblp', 'dyn',
	'load_dyn, no index');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'dblp', 'dync',
	'load_dync, no index');


INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'dblp', 'dynin',
	'load_dyn, index on col 1+2');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'dblp', 'dyncin',
	'load_dync, index on col 1+2');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'dblp', 'dyntr',
	'load_dyn, trie index');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'dblp', 'dynctr',
	'load_dync, trie index');

-- ----------------------------------------------------------------------------
-- Join1 Tests for XSB:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'j1axyd', 'none',
	'Join1 with duplicates, a(X,Y) [V0: no tabling]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'j1axy', 'a',
	'Join1, a(X,Y) [V1: only a tabled]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'j1axy', 'all',
	'Join1, a(X,Y) [V2: all derived preds tabled (subsumptive)]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'j1axy', 'allv',
	'Join1, a(X,Y) [V4: all derived preds tabled, variant tabled]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'j1axy', 'alli',
	'Join1, a(X,Y) [V4: all derived preds tabled, with indexes]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'j1axy', 'allt',
	'Join1, a(X,Y) [V5: all derived preds tabled, with trie index]');

-- ----------------------------------------------------------------------------
-- TCFF Tests for XSB:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'tcff', 'dyn',
	'tc(X,Y) [V1: load_dyn, trie-index for par]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'tcff', 'dync',
	'tc(X,Y) [V2: load_dync, trie-index for par]');

-- ----------------------------------------------------------------------------
-- TCBF Tests for XSB:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'tcbf', 'dyn',
	'tc(1,X) [V1: load_dyn, trie-index for par]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'tcbf',  'dync',
	'tc(1,X) [V2: load_dync, trie-index for par]');

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'tcbfs', 'sldmdc',
	'tc(1,X) [V3: SLDMagic, load_dync, trie-index]');

-- ----------------------------------------------------------------------------
-- Wine Ontology Test for XSB:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'xsb', 'wine', 'idxsub',
	'wine ontology [V1: load_dync, subsumptive tabling, std. indexes]');


-- ============================================================================
-- Tests for YAP:
-- ============================================================================

-- ----------------------------------------------------------------------------
-- DBLP Tests for YAP:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'dblp', '',
	'DBLP Benchmark');

-- ----------------------------------------------------------------------------
-- Join1 Tests for YAP:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'j1axyd', 'none',
	'Join1 with duplicates, a(X,Y) [V0: no tabling]');

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'j1axy', 'a',
	'Join1, a(X,Y) [V1: only a tabled]');

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'j1axy', 'all',
	'Join1, a(X,Y) [V2: all derived preds tabled]');

-- ----------------------------------------------------------------------------
-- TCFF Tests for YAP:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'tcff', 'tab',
	'tc(X,Y) [V1: tc tabled]');

-- ----------------------------------------------------------------------------
-- TBFF Tests for YAP:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'tcbf', 'tab',
	'tc(1,X) [V1: tc tabled]');

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'tcbfs', 'sldmdc',
	'tc(1,X) [V2: with SLDMagic, all preds tabled]');

-- ----------------------------------------------------------------------------
-- Wine Ontology Test for YAP:
-- ----------------------------------------------------------------------------

INSERT INTO BENCH_IMPL VALUES (
	'yap', 'wine', 'idxsub',
	'wine ontology [V1: table 225 derived preds, reorder body lits var->]');

-- ============================================================================
-- Table for Data Files (Input Files to Benchmarks):
-- ============================================================================

CREATE TABLE DATA_FILE(
	INPUT_ID    VARCHAR(20)  NOT NULL,
	SEQ_NO      NUMERIC(3)   NOT NULL,
	LINES       NUMERIC(12)  NOT NULL, -- should be the number of facts
	BYTES       NUMERIC(12)  NOT NULL, -- refers to Datalog facts version
	FILENAME    VARCHAR(40)  NOT NULL, -- without extension
--	DESCRIPTION VARCHAR(80)  NULL,
	CONSTRAINT DATA_FILE_PK
		PRIMARY KEY (INPUT_ID),
	CONSTRAINT DATA_FILE_KEY2
		UNIQUE (SEQ_NO),
	CONSTRAINT DATA_FILE_SEQ_NO_NOT_NEGATIVE
		CHECK(SEQ_NO >= 0),
	CONSTRAINT DATA_FILE_LINES_NOT_NEGATIVE
		CHECK(LINES >= 0),
	CONSTRAINT DATA_FILE_BYTES_NOT_NEGATIVE
		CHECK(BYTES >= 0));

-- wc was used to compute lines and bytes
INSERT INTO DATA_FILE VALUES('b1',   1,  131070,   2488088,'tc_b1_n131k_');
INSERT INTO DATA_FILE VALUES('b2',   2,  262142,   5171672,'tc_b2_n262k_');
INSERT INTO DATA_FILE VALUES('b3',   3,  524286,  10676696,'tc_b3_n524k_');
INSERT INTO DATA_FILE VALUES('c1',   4,    1000,     14780,'tc_c1_n1k_');
INSERT INTO DATA_FILE VALUES('c2',   5,    2000,     31780,'tc_c2_n2k_');
INSERT INTO DATA_FILE VALUES('c3',   6,    4000,     65780,'tc_c3_n4k_');
INSERT INTO DATA_FILE VALUES('kc1',  7, 1000000,  14780000,'tc_kc1_n1k');
INSERT INTO DATA_FILE VALUES('kc2',  8, 4000000,  63560000,'tc_kc2_n2k');
INSERT INTO DATA_FILE VALUES('kn1',  9,  499500,   7382610,'tc_kn1_n1k');
INSERT INTO DATA_FILE VALUES('kn2', 10, 1999000,  31764110,'tc_kn2_n2k');
INSERT INTO DATA_FILE VALUES('m1',  11,    8190,    137016,'tc_m1_n8k_2');
INSERT INTO DATA_FILE VALUES('m2',  12,    8184,    136932,'tc_m2_n8k_8');
INSERT INTO DATA_FILE VALUES('m3',  13,    8160,    136574,'tc_m3_n8k_32');
INSERT INTO DATA_FILE VALUES('m4',  14,    8064,    135106,'tc_m4_n8k_128');
INSERT INTO DATA_FILE VALUES('m5',  15,    7680,    128962,'tc_m5_n8k_512');
INSERT INTO DATA_FILE VALUES('m6',  16,    6144,    103338,'tc_m6_n8k_2048');
INSERT INTO DATA_FILE VALUES('p1',  17,     999,     14767,'tc_p1_n1k_');
INSERT INTO DATA_FILE VALUES('p2',  18,    1999,     31766,'tc_p2_n2k_');
INSERT INTO DATA_FILE VALUES('p3',  19,    3999,     65766,'tc_p3_n4k_');
INSERT INTO DATA_FILE VALUES('s1',  20,    4000,     63560,'tc_s1_n2k_1');
INSERT INTO DATA_FILE VALUES('s2',  21,    6000,     95340,'tc_s2_n2k_2');
INSERT INTO DATA_FILE VALUES('s3',  22,    8000,    127120,'tc_s3_n2k_3');
INSERT INTO DATA_FILE VALUES('s4',  23,   10000,    158900,'tc_s4_n2k_4');
INSERT INTO DATA_FILE VALUES('uc1', 24,   50000,    739017,'tc_uc1_n1k_e50k');
INSERT INTO DATA_FILE VALUES('uc2', 25,  125000,   1847521,'tc_uc2_n1k_e125k');
INSERT INTO DATA_FILE VALUES('uc3', 66,  250000,   3694992,'tc_uc3_n1k_e250k');
INSERT INTO DATA_FILE VALUES('uc4', 27,  200000,   3178006,'tc_uc4_n2k_e200k');
INSERT INTO DATA_FILE VALUES('uc5', 28,  500000,   7945050,'tc_uc5_n2k_e500k');
INSERT INTO DATA_FILE VALUES('uc6', 29, 1000000,  15890038,'tc_uc6_n2k_e1000k');
INSERT INTO DATA_FILE VALUES('un1', 30,   50000,    738969,'tc_un1_n1k_e50k');
INSERT INTO DATA_FILE VALUES('un2', 31,  125000,   1847363,'tc_un2_n1k_e125k');
INSERT INTO DATA_FILE VALUES('un3', 32,  250000,   3694940,'tc_un3_n1k_e250k');
INSERT INTO DATA_FILE VALUES('un4', 33,  200000,   3177933,'tc_un4_n2k_e200k');
INSERT INTO DATA_FILE VALUES('un5', 34,  500000,   7944766,'tc_un5_n2k_e500k');
INSERT INTO DATA_FILE VALUES('un6', 35, 1000000,  15890191,'tc_un6_n2k_e1000k');

INSERT INTO DATA_FILE VALUES('f1',  40,   50000,    689318,'tc_d1000_parsize50000_xsb_nocyc');
INSERT INTO DATA_FILE VALUES('f2',  41,   50000,    689318,'tc_d1000_parsize50000_xsb_cyc');
INSERT INTO DATA_FILE VALUES('f3',  42,  250000,   3446506,'tc_d1000_parsize250000_xsb_nocyc');
INSERT INTO DATA_FILE VALUES('f4',  43,  250000,   3446506,'tc_d1000_parsize250000_xsb_cyc');
INSERT INTO DATA_FILE VALUES('f5',  44,  500000,   6893031,'tc_d1000_parsize500000_xsb_nocyc');
INSERT INTO DATA_FILE VALUES('f6',  45,  500000,   6893031,'tc_d1000_parsize500000_xsb_cyc');
INSERT INTO DATA_FILE VALUES('f7',  46,  500000,   7446477,'tc_d2000_parsize500000_xsb_nocyc');
INSERT INTO DATA_FILE VALUES('f8',  47,  500000,   7446477,'tc_d2000_parsize500000_xsb_cyc');
INSERT INTO DATA_FILE VALUES('f9',  48, 1000000,  14892982,'tc_d2000_parsize1000000_xsb_nocyc');
INSERT INTO DATA_FILE VALUES('f10', 49, 1000000,  14892982,'tc_d2000_parsize1000000_xsb_cyc');

INSERT INTO DATA_FILE VALUES('10k', 50,   50000,    639300,'d1000_relsize10000_xsb_cyc');
INSERT INTO DATA_FILE VALUES('50k', 51,  250000,   3196504,'d1000_relsize50000_xsb_cyc');
INSERT INTO DATA_FILE VALUES('250k',52, 1250000,  15982480,'d1000_relsize250000_xsb_cyc');

INSERT INTO DATA_FILE VALUES('std', 60, 2437867, 128444409,'dblp');
INSERT INTO DATA_FILE VALUES('big', 61,50221773,3082908204,'dblp_big');

INSERT INTO DATA_FILE VALUES('wdat',70,     654,     26386, 'wine_data');


-- ============================================================================
-- Table for Input Files to Benchmarks:
-- ============================================================================

CREATE TABLE BENCH_INPUT(
	BENCH       VARCHAR(20)  NOT NULL,
	INPUT_ID    VARCHAR(20)  NOT NULL,
	CONSTRAINT BENCH_INPUT_PK
		PRIMARY KEY (BENCH, INPUT_ID),
	CONSTRAINT BENCH_INPUT_REF_BENCHMARK
		FOREIGN KEY (BENCH) REFERENCES BENCHMARK,
	CONSTRAINT BENCH_INPUT_REF_DATA_FILE
		FOREIGN KEY (INPUT_ID) REFERENCES DATA_FILE);

INSERT INTO BENCH_INPUT VALUES ('dblp',   'std' );
INSERT INTO BENCH_INPUT VALUES ('dblp',   'big' );

INSERT INTO BENCH_INPUT VALUES ('j1axy',  '10k' );
INSERT INTO BENCH_INPUT VALUES ('j1axy',  '50k' );
INSERT INTO BENCH_INPUT VALUES ('j1axy',  '250k');

INSERT INTO BENCH_INPUT VALUES ('j1axyd', '10k' );
INSERT INTO BENCH_INPUT VALUES ('j1axyd', '50k' );
INSERT INTO BENCH_INPUT VALUES ('j1axyd', '250k');

INSERT INTO BENCH_INPUT VALUES ('tcff',   'b1'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'b2'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'b3'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'c1'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'c2'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'c3'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'kc1' );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'kc2' );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'kn1' );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'kn2' );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'm1'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'm2'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'm3'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'm4'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'm5'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'm6'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'p1'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'p2'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'p3'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   's1'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   's2'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   's3'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   's4'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'uc1' );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'uc2' );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'uc3' );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'uc4' );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'uc5' );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'uc6' );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'un1' );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'un2' );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'un3' );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'un4' );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'un5' );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'un6' );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'f1'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'f2'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'f3'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'f4'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'f5'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'f6'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'f7'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'f8'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'f9'  );
INSERT INTO BENCH_INPUT VALUES ('tcff',   'f10' );

INSERT INTO BENCH_INPUT VALUES ('tcbf',   'b1'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'b2'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'b3'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'c1'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'c2'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'c3'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'kc1' );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'kc2' );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'kn1' );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'kn2' );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'm1'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'm2'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'm3'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'm4'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'm5'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'm6'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'p1'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'p2'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'p3'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   's1'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   's2'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   's3'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   's4'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'uc1' );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'uc2' );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'uc3' );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'uc4' );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'uc5' );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'uc6' );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'un1' );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'un2' );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'un3' );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'un4' );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'un5' );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'un6' );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'f1'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'f2'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'f3'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'f4'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'f5'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'f6'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'f7'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'f8'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'f9'  );
INSERT INTO BENCH_INPUT VALUES ('tcbf',   'f10' );

INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'b1'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'b2'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'b3'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'c1'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'c2'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'c3'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'kc1' );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'kc2' );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'kn1' );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'kn2' );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'm1'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'm2'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'm3'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'm4'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'm5'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'm6'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'p1'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'p2'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'p3'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  's1'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  's2'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  's3'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  's4'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'uc1' );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'uc2' );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'uc3' );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'uc4' );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'uc5' );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'uc6' );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'un1' );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'un2' );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'un3' );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'un4' );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'un5' );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'un6' );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'f1'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'f2'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'f3'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'f4'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'f5'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'f6'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'f7'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'f8'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'f9'  );
INSERT INTO BENCH_INPUT VALUES ('tcbfs',  'f10' );

INSERT INTO BENCH_INPUT VALUES ('wine',   'wdat');

INSERT INTO BENCH_INPUT VALUES ('loadd',  'std' );
INSERT INTO BENCH_INPUT VALUES ('loadd',  'big' );

--INSERT INTO BENCH_INPUT VALUES ( 'loadt', ...);
--INSERT INTO BENCH_INPUT VALUES (  'set1', ...);
--INSERT INTO BENCH_INPUT VALUES (  'set2', ...);

-- ============================================================================
-- Table for Results of Benchmark Runs (Test Runs):
-- ============================================================================


CREATE TABLE BENCH_RUN(
	RUN_DATE    DATE         NOT NULL,
	RUN_NO      NUMERIC(4)   NOT NULL,
	PROG        VARCHAR(20)  NOT NULL,
	VER         NUMERIC(4)   NOT NULL,
	MACHINE     VARCHAR(20)  NOT NULL,
	BENCH       VARCHAR(20)  NOT NULL,
	IMPL        VARCHAR(20)  NOT NULL,
	INPUT_ID    VARCHAR(20)  NOT NULL,
	LOAD_TIME   NUMERIC(8,3) NULL,
	EXEC_TIME   NUMERIC(8,3) NULL,
	TOTAL_TIME  NUMERIC(8,3) NULL,
	USER_TIME   NUMERIC(8,3) NULL,
	SYS_TIME    NUMERIC(8,3) NULL,
	REAL_TIME   NUMERIC(8,3) NOT NULL,
	MEM         NUMERIC(8,3) NULL,
	STATUS      VARCHAR(80)  NULL,
	REMARK      VARCHAR(800) NULL,
        CONSTRAINT  RUN_NO_POSITIVE
		CHECK(RUN_NO > 0),
        CONSTRAINT  LOAD_TIME_NONNEGATIVE
		CHECK(LOAD_TIME >= 0),
        CONSTRAINT  EXEC_TIME_NONNEGATIVE
		CHECK(EXEC_TIME >= 0),
        CONSTRAINT  TOTAL_TIME_NONNEGATIVE
		CHECK(TOTAL_TIME >= 0),
        CONSTRAINT  USER_TIME_NONNEGATIVE
		CHECK(USER_TIME >= 0),
        CONSTRAINT  SYS_TIME_NONNEGATIVE
		CHECK(SYS_TIME >= 0),
        CONSTRAINT  REAL_TIME_NONNEGATIVE
		CHECK(REAL_TIME >= 0),
        CONSTRAINT  MEM_NONNEGATIVE
		CHECK(MEM >= 0),
        CONSTRAINT  BENCH_RUN_PK
		PRIMARY KEY(RUN_DATE,RUN_NO,MACHINE,PROG,VER),
        CONSTRAINT  BENCH_RUN_REF_BENCH_IMPL
		FOREIGN KEY(PROG, BENCH, IMPL) REFERENCES BENCH_IMPL,
        CONSTRAINT  BENCH_RUN_REF_BENCH_INPUT
		FOREIGN KEY(BENCH, INPUT_ID) REFERENCES BENCH_INPUT,
	CONSTRAINT  BENCH_RUN_REF_PROG_VER
		FOREIGN KEY(PROG, VER, MACHINE) REFERENCES PROG_VER);

-- ============================================================================
-- Full Statistical Evaluation of Run Data:
-- ============================================================================

CREATE VIEW RUN_STATISTICS AS
SELECT BENCH, INPUT_ID, MACHINE, PROG, VER,
	ROUND(AVG(LOAD_TIME),3) AS AVG_LOAD_TIME,
	MIN(LOAD_TIME) AS MIN_LOAD_TIME,
	MAX(LOAD_TIME) AS MAX_LOAD_TIME,
	MAX(LOAD_TIME)-MIN(LOAD_TIME) AS DIFF_LOAD_TIME,
	ROUND(AVG(EXEC_TIME),3) AS AVG_EXEC_TIME,
	MIN(EXEC_TIME) AS MIN_EXEC_TIME,
	MAX(EXEC_TIME) AS MAX_EXEC_TIME,
	MAX(EXEC_TIME)-MIN(EXEC_TIME) AS DIFF_EXEC_TIME,
	ROUND(AVG(TOTAL_TIME),3) AS AVG_TOTAL_TIME,
	MIN(TOTAL_TIME) AS MIN_TOTAL_TIME,
	MAX(TOTAL_TIME) AS MAX_TOTAL_TIME,
	MAX(TOTAL_TIME)-MIN(TOTAL_TIME) AS DIFF_TOTAL_TIME,
	ROUND(AVG(USER_TIME),3) AS AVG_USER_TIME,
	MIN(USER_TIME) AS MIN_USER_TIME,
	MAX(USER_TIME) AS MAX_USER_TIME,
	MAX(USER_TIME)-MIN(USER_TIME) AS DIFF_USER_TIME,
	ROUND(AVG(SYS_TIME),3) AS AVG_SYS_TIME,
	MIN(SYS_TIME) AS MIN_SYS_TIME,
	MAX(SYS_TIME) AS MAX_SYS_TIME,
	MAX(SYS_TIME)-MIN(SYS_TIME) AS DIFF_SYS_TIME,
	ROUND(AVG(REAL_TIME),3) AS AVG_REAL_TIME,
	MIN(REAL_TIME) AS MIN_REAL_TIME,
	MAX(REAL_TIME) AS MAX_REAL_TIME,
	MAX(REAL_TIME)-MIN(REAL_TIME) AS DIFF_REAL_TIME,
	ROUND(AVG(MEM),3) AS AVG_MEM,
	MIN(MEM) AS MIN_MEM,
	MAX(MEM) AS MAX_MEM,
	MAX(MEM)-MIN(MEM) AS DIFF_MEM,
	COUNT(*) AS NUM_BENCH_RUN
FROM BENCH_RUN
GROUP BY BENCH, INPUT_ID, MACHINE, PROG, VER
ORDER BY BENCH, INPUT_ID, MACHINE, PROG, VER;

