-- ============================================================================
-- Project:	Deductive Database
-- Filename:	bench_db.sql
-- Purpose:	Database for Benchmark Runs
-- Last Change:	11.05.2018
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2016-2018 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ============================================================================
-- Delete Old Versions of the Tables:
-- ============================================================================

-- When this script is executed the first time,
-- these commands generate errors (because the tables/views do not exist).

DROP VIEW  DBS_RESULTS;
DROP VIEW  BACH_RESULTS;
DROP VIEW  BEST_OPT;
DROP VIEW  RUN_STATISTICS;

DROP TABLE RUNS;
DROP TABLE TESTS;
DROP TABLE PROG_VER;
DROP TABLE PROGRAMS;
DROP TABLE BENCHMARKS;
DROP TABLE MACHINES;

-- ============================================================================
-- List of Machines on which Benchmarks are Executed:
-- ============================================================================

CREATE TABLE MACHINES(
	MACHINE     VARCHAR(20)  NOT NULL,
	SEQ_NO      NUMERIC(2)   NOT NULL,
	NUM_CPUS    NUMERIC(4)   NOT NULL,
	CPU         VARCHAR(60)  NOT NULL,
	CPU_CORES   NUMERIC(4)   NULL,
        CPU_THREADS NUMERIC(4)   NULL,
	GHZ         NUMERIC(5,2) NULL,
	ARCH        VARCHAR(20)  NULL,
	RAM         NUMERIC(8,3) NOT NULL,
	NUM_DISKS   NUMERIC(4)   NULL,
        DISK        VARCHAR(40)  NULL,
	SSD         CHAR(1)      NULL,
	OS          VARCHAR(40)  NULL,
	OS_CORE     VARCHAR(40)  NULL,
	CONSTRAINT MACHINES_PK
		PRIMARY KEY(MACHINE),
	CONSTRAINT MACHINES_KEY_SEQ
		UNIQUE (SEQ_NO),
	CONSTRAINT MACHINES_SEQ_NO_POSITIVE
		CHECK(SEQ_NO > 0),
	CONSTRAINT MACHINES_NUM_CPUS_POSITIVE
		CHECK(NUM_CPUS > 0),
	CONSTRAINT MACHINES_CPU_CORES_POSITIVE
		CHECK(CPU_CORES > 0),
	CONSTRAINT MACHINES_CPU_THREADS_POSITIVE
		CHECK(CPU_THREADS > 0),
	CONSTRAINT MACHINES_RAM_POSITIVE
		CHECK(RAM > 0),
	CONSTRAINT MACHINES_NUM_DISKS_POSITIVE
		CHECK(NUM_DISKS > 0),
	CONSTRAINT MACHINES_SSD_YN
		CHECK(SSD IN ('Y','N')));

INSERT INTO MACHINES VALUES(
	'bach', 1,
	1, 'Xeon Intel 2011 E5-1620v4 4/8x 3,5GHz', 4, 8, 3.5, 'x86_64',
	16,
	1, 'Samsung SSD 850 EVO 500GB', 'Y',
	'CentOS Linux release 7.4.1708 (Core)',
	'Linux 3.10.0-693.21.1.el7.x86_64 x86_64');

INSERT INTO MACHINES VALUES(
	'dbs1', 2,
	2, 'Intel(R) Xeon(R) CPU E5-2630 v4 @ 2.20GHz', 10, 20, 2.2, 'x86_64',
	64,
	NULL, NULL, NULL,
	'Debian GNU/Linux 8.10 (jessie)',
	'Linux 3.16.0-5-amd64 x86_64');

-- Note that the CORE might not be current. It changes with every update.
-- It was current when we started the benchmarks in May 2018.
-- It gives some impression of the machine and its operating system.

-- ============================================================================
-- List of Benchmarks:
-- ============================================================================


CREATE TABLE BENCHMARKS(
	BENCHMARK   VARCHAR(20)  NOT NULL,
	SEQ_NO      NUMERIC(2)   NOT NULL,
	HEADLINE    VARCHAR(80)  NOT NULL,
	CONSTRAINT BENCHMARKS_SEQ_NONNEGATIVE
		CHECK(SEQ_NO >= 0),
	CONSTRAINT BENCHMARKS_PK
		PRIMARY KEY (BENCHMARK),
	CONSTRAINT BENCHMARKS_KEY_SEQ
		UNIQUE (SEQ_NO));

INSERT INTO BENCHMARKS VALUES (
	'DBLP', 1,
	'DBLP Benchmark');

INSERT INTO BENCHMARKS VALUES (
	'JOIN1', 2,
	'The Join1 Benchmark');

INSERT INTO BENCHMARKS VALUES (
	'JOIN1_DUP', 3,
	'The Join1 Benchmark (without duplicate elimination)');

INSERT INTO BENCHMARKS VALUES (
	'TCFF', 4,
	'Transitive Closure Benchmark without Query Bindings');

INSERT INTO BENCHMARKS VALUES (
	'TCBF', 5,
	'Transitive Closure Benchmark with the First Argument Bound');

INSERT INTO BENCHMARKS VALUES (
	'TCBF_SLDMAGIC', 6,
	'Transitive Closure Benchmark, first arg bound, with SLDMagic');

INSERT INTO BENCHMARKS VALUES (
	'WINE', 7,
	'Wine Ontology Benchmark');

INSERT INTO BENCHMARKS VALUES (
	'LOAD_DBLP', 8,
	'Test of Loader for DBLP Data');

INSERT INTO BENCHMARKS VALUES (
	'LOAD_TC', 9,
	'Test of Loader for Transitive Closure');

INSERT INTO BENCHMARKS VALUES (
	'SET1', 10,
	'Test of Set Insertion and Lookup (One Column)');

INSERT INTO BENCHMARKS VALUES (
	'SET2', 11,
	'Test of Set Insertion and Lookup (Two Columns)');

-- ============================================================================
-- List of Programs to be Tested/Compared:
-- ============================================================================

CREATE TABLE PROGRAMS(
	PROG        VARCHAR(20)  NOT NULL,
	SEQ_NO      NUMERIC(2)   NOT NULL,
	FULL_NAME   VARCHAR(40)  NOT NULL,
	URL         VARCHAR(80)  NULL,
	REMARK      VARCHAR(800) NULL,
	CONSTRAINT PROGRAMS_SEQ_NONNEGATIVE
		CHECK(SEQ_NO >= 0),
	CONSTRAINT PROGRAMS_PK
		PRIMARY KEY (PROG),
	CONSTRAINT PROGRAMS_KEY_SEQ
		UNIQUE (SEQ_NO));

INSERT INTO PROGRAMS VALUES (
	'ydb', 1, 'Push (ydb)',
	'http://users.informatik.uni-halle.de/~brass/push/',
	NULL);

INSERT INTO PROGRAMS VALUES (
	'bam', 2, 'Push (bam)',
	'http://users.informatik.uni-halle.de/~brass/push/',
	NULL);

INSERT INTO PROGRAMS VALUES (
	'xsb', 3, 'XSB',
	'http://xsb.sourceforge.net/',
	NULL);

INSERT INTO PROGRAMS VALUES (
	'yap', 4, 'YAProlog',
	'https://www.dcc.fc.up.pt/~vsc/Yap/',
	NULL);

INSERT INTO PROGRAMS VALUES (
	'souffle', 5, 'Souffle',
	'http://souffle-lang.org/',
	NULL);

INSERT INTO PROGRAMS VALUES (
	'dlv', 6, 'DLV',
	'http://www.dlvsystem.com/',
	NULL);

INSERT INTO PROGRAMS VALUES (
	'mercury', 7, 'Melbourne Mercury',
	'http://www.mercurylang.org/',
	NULL);

INSERT INTO PROGRAMS VALUES (
	'hsql', 8, 'HSQLDB',
	'http://hsqldb.org/',
	NULL);

INSERT INTO PROGRAMS VALUES (
	'swipl', 9, 'SWI-Prolog',
	'http://www.swi-prolog.org/',
	NULL);

-- ============================================================================
-- Table for Installed Program Versions on Machines:
-- ============================================================================

-- This table lists program versions
-- that are or were installed on a test machine.
-- They are identified here by a number that is unique together with
-- the program name and the machine.
-- These three elements (Program, Version number, and machine)
-- are also encoded in the file names with the test results.
--
-- Note that we use a simple sequential number VER for the version in the key,
-- not the real version number (which can be an arbitrary string).
-- The real version number is available in column VER_NAME
-- and can be used for output.
--
-- I try to make sure that the same VER_NAME of a program gets the same VER
-- number even on different machines, but the database schema does not
-- require this.
-- It is possible that a VER_NAME corresponds to different VER numbers,
-- for instance, if a program is compiled with different compilers or
-- compiler settings. This would require a new VER number.
--
-- Only program versions that are listed here can appear in the test runs.
--
-- This table also define a current version of a program on a machine
-- (by STATUS='C').  Some views show only results for the current version.
-- It is also possible to define a previous version (STATUS='P') as reference,
-- if the result of a program update should be evaluated.
-- Finally, one can mark an alternative version (STATUS='A'),
-- e.g. compiled with a different compiler or compiler options,
-- which can also be used for comparison.
--
-- VER_ADDTEXT should be concatenated with VER_NAME
-- to get the full name of the version.
-- This table also permits to store additional information about a version.
-- For instance, XSB outputs configuration information when started.

CREATE TABLE PROG_VER (
	PROG        VARCHAR(20)  NOT NULL,
	VER         NUMERIC(4)   NOT NULL,
	MACHINE     VARCHAR(20)  NOT NULL,
	VER_NAME    VARCHAR(20)  NOT NULL,
	VER_ADDTEXT VARCHAR(80)  NOT NULL,
	VER_DATE    DATE         NULL,
	COMPILER    VARCHAR(80)  NOT NULL,
	STATUS      CHAR(1)      NOT NULL,
	REMARK      VARCHAR(800) NULL,
	CONSTRAINT PROG_VER_PK
		PRIMARY KEY (PROG, VER, MACHINE),
	CONSTRAINT PROG_VER_REF_PROGRAMS
		FOREIGN KEY (PROG) REFERENCES PROGRAMS,
	CONSTRAINT PROG_VER_REF_MACHINES
		FOREIGN KEY (MACHINE) REFERENCES MACHINES,
	CONSTRAINT PROG_VER_STATUS_VALID
		CHECK(STATUS IN ('C','P','A',' ')));

INSERT INTO PROG_VER VALUES (
	'ydb', 1, 'bach',
	'0.1', '', '2016-11-21',
	'gcc version 4.8.5 (-O2)',
	'C',
	NULL);

INSERT INTO PROG_VER VALUES (
	'ydb', 1, 'dbs1',
	'0.1', '', '2016-11-21',
	'gcc version 4.9.2 (-O2)',
	'C',
	NULL);

INSERT INTO PROG_VER VALUES (
	'bam', 1, 'bach',
	'0.1a', '', '2018-04-24',
	'gcc version 4.8.5 (-O2)',
	'C',
	NULL);

INSERT INTO PROG_VER VALUES (
	'bam', 1, 'dbs1',
	'0.1a', '', '2018-04-24',
	'gcc version 4.9.2 (-O2)',
	'C',
	NULL);

INSERT INTO PROG_VER VALUES (
	'xsb', 1, 'dbs1',
	'3.7.', ' (Clan MacGregor)', '2016-07-06',
	'',
	'C',
	'x86_64-unknown-linux-gnu 64 bits; ' ||
		'mode: optimal; engine: slg-wam; scheduling: local');

INSERT INTO PROG_VER VALUES (
	'xsb', 2, 'bach',
	'3.8.0', ' (Three-Buck Chuck)', '2017-10-28',
	'',
	'C',
	'x86_64-unknown-linux-gnu 64 bits; ' ||
		'mode: optimal; engine: slg-wam; scheduling: local');

INSERT INTO PROG_VER VALUES (
	'yap', 1, 'dbs1',
	'6.2.2', ' (x86_64-linux)', '2011-10-21',
	'',
	'C',
	NULL);

INSERT INTO PROG_VER VALUES (
	'yap', 2, 'bach',
	'6.3.3', ' (x86_64-linux)', '2013-01-20',
	'',
	'C',
	NULL);

INSERT INTO PROG_VER VALUES (
	'swipl', 1, 'dbs1',
	'7.7.15', ' (x86_64-linux)', '2018-06-01',
	'',
	'C',
	NULL);

-- ============================================================================
-- Table for Tests (A Benchmark Executed by a Program with Specific Options):
-- ============================================================================

-- A BENCH_ID is program-specific.
-- E.g. 'tcff_1_f5' is the TCFF benchmark,
-- but with implementation variant 1.
-- This corresponds to options set in other systems,
-- e.g. a selection of indexes.
-- Therefore, this part has a meaning only for a specific program.
-- The part f5 encodes the input data file.
-- Note that the data files may depend also on the program,
-- because each program may have its own syntax.
-- Obviously, the data should be the same to make the tests comparable.
-- It is assumed that the same INPUT_NO means that the data are the same.

CREATE TABLE TESTS(
	PROG        VARCHAR(20)  NOT NULL,
	BENCH_ID    VARCHAR(20)  NOT NULL,
	BENCHMARK   VARCHAR(20)  NOT NULL,
	INPUT_NO    NUMERIC(2)   NOT NULL,
	INPUT_FILE  VARCHAR(40)  NOT NULL,
	OPTIONS     VARCHAR(40)  NOT NULL,
	DESCRIPTION VARCHAR(80)  NULL,
	CONSTRAINT TESTS_PK
		PRIMARY KEY (PROG, BENCH_ID),
	CONSTRAINT TESTS_REF_BENCHMARKS
		FOREIGN KEY (BENCHMARK) REFERENCES BENCHMARKS,
	CONSTRAINT TESTS_REF_PROGRAMS
		FOREIGN KEY (PROG) REFERENCES PROGRAMS);


-- ============================================================================
-- Tests for bam:
-- ============================================================================

-- ----------------------------------------------------------------------------
-- Join1 Tests for bam:
-- ----------------------------------------------------------------------------

-- j1axy_1_*:

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_1_test',
	'JOIN1', 0, 'd1000_test.P',
	'V1',
	'Join1, a(X,Y) [V1: RelAttr, -goto, fullDupCh] test');

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_1_10k',
	'JOIN1', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V1',
	'Join1, a(X,Y) [V1: RelAttr, -goto, fullDupCh] 10K*5');

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_1_50k',
	'JOIN1', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V1',
	'Join1, a(X,Y) [V1: RelAttr, -goto, fullDupCh] 50K*5');

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_1_250k',
	'JOIN1', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V1',
	'Join1, a(X,Y) [V1: RelAttr, -goto, fullDupCh] 250K*5');

-- j1axy_2_*:

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_2_test',
	'JOIN1', 0, 'd1000_test.P',
	'V2',
	'Join1, a(X,Y) [V2: no goto, bitmap-dupcheck], test');

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_2_10k',
	'JOIN1', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V2',
	'Join1, a(X,Y) [V2: no goto, bitmap-dupcheck], 10K*5');

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_2_50k',
	'JOIN1', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V2',
	'Join1, a(X,Y) [V2: no goto, bitmap-dupcheck], 50K*5');

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_2_250k',
	'JOIN1', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V2',
	'Join1, a(X,Y) [V2: no goto, bitmap-dupcheck], 250K*5');

-- j1axy_3_*:

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_3_test',
	'JOIN1', 0, 'd1000_test.P',
	'V3',
	'Join1, a(X,Y) [V3: goto, bitmap-dupC, cursor], test');

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_3_10k',
	'JOIN1', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V3',
	'Join1, a(X,Y) [V3: goto, bitmap-dupC, cursor], 10K*5');

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_3_50k',
	'JOIN1', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V3',
	'Join1, a(X,Y) [V3: goto, bitmap-dupC, cursor], 50K*5');

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_3_250k',
	'JOIN1', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V3',
	'Join1, a(X,Y) [V3: goto, bitmap-dupC, cursor], 250K*5');

-- j1axy_4_*:

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_4_test',
	'JOIN1', 0, 'd1000_test.P',
	'V4: Functions',
	'Join1, a(X,Y) [V4: functions, bitmap-dupC], test');

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_4_10k',
	'JOIN1', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V4: Functions',
	'Join1, a(X,Y) [V4: functions, bitmap-dupC], 10K*5');

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_4_50k',
	'JOIN1', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V4: Functions',
	'Join1, a(X,Y) [V4: functions, bitmap-dupC], 50K*5');

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_4_250k',
	'JOIN1', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V4: Functions',
	'Join1, a(X,Y) [V4: functions, bitmap-dupC], 250K*5');

-- j1axy_5_*:

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_5_test',
	'JOIN1', 0, 'd1000_test.P',
	'V5',
	'Join1, a(X,Y) [V5: fun without args, bitmap], test');

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_5_10k',
	'JOIN1', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V5',
	'Join1, a(X,Y) [V5: fun without args, bitmap], 10K*5');

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_5_50k',
	'JOIN1', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V5',
	'Join1, a(X,Y) [V5: fun without args, bitmap], 50K*5');

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_5_250k',
	'JOIN1', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V5',
	'Join1, a(X,Y) [V5: fun without args, bitmap], 250K*5');

-- j1axy_6_*:

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_6_test',
	'JOIN1', 0, 'd1000_test.P',
	'V6: Abstract Machine',
	'Join1, a(X,Y) [V6: Abstract Machine, bitmap], test');

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_6_10k',
	'JOIN1', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V6: Abstract Machine',
	'Join1, a(X,Y) [V6: Abstract Machine, bitmap], 10K*5');

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_6_50k',
	'JOIN1', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V6: Abstract Machine',
	'Join1, a(X,Y) [V6: Abstract Machine, bitmap], 50K*5');

INSERT INTO TESTS VALUES (
	'bam', 'j1axy_6_250k',
	'JOIN1', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V6: Abstract Machine',
	'Join1, a(X,Y) [V6: Abstract Machine, bitmap], 250K*5');

-- ----------------------------------------------------------------------------
-- Transitive Closure Tests for bam (TCFF - Both Arguments Free):
-- ----------------------------------------------------------------------------

-- tcff_1_*:

INSERT INTO TESTS VALUES (
	'bam', 'tcff_1_test',
	'TCFF', 0, 'tc_test.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], Small Test File');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_1_f1',
	'TCFF', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_1_f2',
	'TCFF', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_1_f3',
	'TCFF', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_1_f4',
	'TCFF', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_1_f5',
	'TCFF', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_1_f6',
	'TCFF', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_1_f7',
	'TCFF', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_1_f8',
	'TCFF', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_1_f9',
	'TCFF', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_1_f10',
	'TCFF', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 10: 2k-1M-cyc');

-- tcff_2_*:

INSERT INTO TESTS VALUES (
	'bam', 'tcff_2_test',
	'TCFF', 0, 'tc_test.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], Small Test File');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_2_f1',
	'TCFF', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_2_f2',
	'TCFF', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_2_f3',
	'TCFF', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_2_f4',
	'TCFF', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_2_f5',
	'TCFF', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_2_f6',
	'TCFF', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_2_f7',
	'TCFF', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_2_f8',
	'TCFF', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_2_f9',
	'TCFF', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_2_f10',
	'TCFF', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 10: 2k-1M-cyc');

-- tcff_3_*:

INSERT INTO TESTS VALUES (
	'bam', 'tcff_3_test',
	'TCFF', 0, 'tc_test.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], Small Test File');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_3_f1',
	'TCFF', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_3_f2',
	'TCFF', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_3_f3',
	'TCFF', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_3_f4',
	'TCFF', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_3_f5',
	'TCFF', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_3_f6',
	'TCFF', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_3_f7',
	'TCFF', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_3_f8',
	'TCFF', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_3_f9',
	'TCFF', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_3_f10',
	'TCFF', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 10: 2k-1M-cyc');

-- tcff_4_*:

INSERT INTO TESTS VALUES (
	'bam', 'tcff_4_test',
	'TCFF', 0, 'tc_test.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], Small Test File');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_4_f1',
	'TCFF', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_4_f2',
	'TCFF', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_4_f3',
	'TCFF', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_4_f4',
	'TCFF', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_4_f5',
	'TCFF', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_4_f6',
	'TCFF', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_4_f7',
	'TCFF', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_4_f8',
	'TCFF', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_4_f9',
	'TCFF', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_4_f10',
	'TCFF', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 10: 2k-1M-cyc');

-- tcff_5_*:

INSERT INTO TESTS VALUES (
	'bam', 'tcff_5_test',
	'TCFF', 0, 'tc_test.P',
	'V5: abstract machine',
	'tc(X,Y) [V5: Abstract Machine], Small Test File');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_5_f1',
	'TCFF', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V5: abstract machine',
	'tc(X,Y) [V5: Abstract Machine], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_5_f2',
	'TCFF', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V5: abstract machine',
	'tc(X,Y) [V5: Abstract Machine], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_5_f3',
	'TCFF', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V5: abstract machine',
	'tc(X,Y) [V5: Abstract Machine], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_5_f4',
	'TCFF', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V5: abstract machine',
	'tc(X,Y) [V5: Abstract Machine], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_5_f5',
	'TCFF', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V5: abstract machine',
	'tc(X,Y) [V5: Abstract Machine], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_5_f6',
	'TCFF', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V5: abstract machine',
	'tc(X,Y) [V5: Abstract Machine], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_5_f7',
	'TCFF', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V5: abstract machine',
	'tc(X,Y) [V5: Abstract Machine], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_5_f8',
	'TCFF', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V5: abstract machine',
	'tc(X,Y) [V5: Abstract Machine], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_5_f9',
	'TCFF', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V5: abstract machine',
	'tc(X,Y) [V5: Abstract Machine], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'bam', 'tcff_5_f10',
	'TCFF', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V5: abstract machine',
	'tc(X,Y) [V5: Abstract Machine], File 10: 2k-1M-cyc');

-- ----------------------------------------------------------------------------
-- Data Loader Tests for bam:
-- ----------------------------------------------------------------------------

INSERT INTO TESTS VALUES (
	'bam', 'LoadTC',
	'LOAD_TC', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V1: Handcrafted Loader',
	'transitive closure data file (with handcrafted loader)');

INSERT INTO TESTS VALUES (
	'bam', 'LoadTCGen',
	'LOAD_TC', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V2: General Loader',
	'transitive closure data file (with general loader)');

-- ----------------------------------------------------------------------------
-- Set Implementation Tests for bam (One Column):
-- ----------------------------------------------------------------------------


INSERT INTO TESTS VALUES (
	'bam', 'set_1e_test',
	'SET1', 1, '1col_10_rows_seq',
	'V1: extendible hashtab',
	'Set with 1 column, extendible Hash table, 10 rows seq.');

INSERT INTO TESTS VALUES (
	'bam', 'set_1e_M',
	'SET1', 2, '1col_1M_rows_seq',
	'V1: extendible hashtab',
	'Set with 1 column, extendible Hash table, 1 mio rows seq.');

INSERT INTO TESTS VALUES (
	'bam', 'set_1e_M2',
	'SET1', 3, '1col_1M_rows_mix',
	'V1: extendible hashtab',
	'Set with 1 column, extendible Hash table, 1 mio rows mix.');

INSERT INTO TESTS VALUES (
	'bam', 'set_1e_H',
	'SET1', 4, '1col_100M_rows_mix',
	'V1: extendible hashtab',
	'Set with 1 column, extendible Hash table, 100 mio rows mix.');

INSERT INTO TESTS VALUES (
	'bam', 'set_1e_G',
	'SET1', 5, '1col_1G_rows_mix',
	'V1: extendible hashtab',
	'Set with 1 column, extendible Hash table, 1 billion rows');

-- ----------------------------------------------------------------------------
-- Set Implementation Tests for bam (Two Columns):
-- ----------------------------------------------------------------------------

INSERT INTO TESTS VALUES (
	'bam', 'set_2e_test',
	'SET2', 6, '2col_10_rows_seq',
	'V1: extendible hashtab',
	'Set with 2 columns, extendible Hash table, 10 rows seq.');

INSERT INTO TESTS VALUES (
	'bam', 'set_2e_M',
	'SET2', 7, '2col_1M_rows_seq',
	'V1: extendible hashtab',
	'Set with 2 columns, extendible Hash table, 1 mio rows seq.');

INSERT INTO TESTS VALUES (
	'bam', 'set_2e_M2',
	'SET2', 8, '2col_1M_rows_mix',
	'V1: extendible hashtab',
	'Set with 2 columns, extendible Hash table, 1 mio rows mix.');

INSERT INTO TESTS VALUES (
	'bam', 'set_2e_H',
	'SET2', 9, '2col_100M_rows_mix',
	'V1: extendible hashtab',
	'Set with 2 columns, extendible Hash table, 100 mio rows');

INSERT INTO TESTS VALUES (
	'bam', 'set_2e_G',
	'SET2', 10, '2col_1G_rows_mix',
	'V1: extendible hashtab',
	'Set with 2 columns, extendible Hash table, 1 billion rows');

-- ============================================================================
-- Tests for ydb:
-- ============================================================================

-- ----------------------------------------------------------------------------
-- DBLP Tests for ydb:
-- ----------------------------------------------------------------------------

-- dblp_1_*:

INSERT INTO TESTS VALUES (
	'ydb', 'dblp_1_test',
	'DBLP', 0, 'dblp_test.data',
	'V1: RelLocalVars',
	'DBLP Bench. [V1: Handwritten loader, Rel in Local Vars] TestFile');

INSERT INTO TESTS VALUES (
	'ydb', 'dblp_1',
	'DBLP', 1, 'dblp.data',
	'V1: RelLocalVars',
	'DBLP Bench. [V1: Handwritten loader, Rel in Local Vars]');

INSERT INTO TESTS VALUES (
	'ydb', 'dblp_1_big',
	'DBLP', 2, 'dblp_big.data',
	'V1: RelLocalVars',
	'DBLP Bench. [V1: Handwritten loader, Rel in Local Vars] 3GB');

-- dblp_2_*:

INSERT INTO TESTS VALUES (
	'ydb', 'dblp_2_test',
	'DBLP', 0, 'dblp_test.data',
	'V2: Cursor Interface',
	'DBLP Bench. [V2: Cursor Interface, Rel+Var->Attr] TestFile');

INSERT INTO TESTS VALUES (
	'ydb', 'dblp_2',
	'DBLP', 1, 'dblp.data',
	'V2: Cursor Interface',
	'DBLP Bench. [V2: Cursor Interface, Rel+Var->Attr]');

INSERT INTO TESTS VALUES (
	'ydb', 'dblp_2_big',
	'DBLP', 2, 'dblp_big.data',
	'V2: Cursor Interface',
	'DBLP Bench. [V2: Cursor Interface, Rel+Var->Attr] 3GB');

-- dblp_3_*:

INSERT INTO TESTS VALUES (
	'ydb', 'dblp_3_test',
	'DBLP', 0, 'dblp_test.data',
	'V3: Separate Objects',
	'DBLP Bench. [V3: Separate Objects] TestFile');

INSERT INTO TESTS VALUES (
	'ydb', 'dblp_3',
	'DBLP', 1, 'dblp.data',
	'V3: Separate Objects',
	'DBLP Bench. [V3: Separate Objects]');

INSERT INTO TESTS VALUES (
	'ydb', 'dblp_3_big',
	'DBLP', 2, 'dblp_big.data',
	'V3: Separate Objects',
	'DBLP Bench. [V3: Separate Objects] 3GB');

-- ----------------------------------------------------------------------------
-- Join1 Tests for ydb:
-- ----------------------------------------------------------------------------

-- j1axy_1_*:

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_1_test',
	'JOIN1_DUP', 0, 'd1000_test.P',
	'V1',
	'Join1, a(X,Y) Bench. [V1: Rel in Attr, no dupcheck] test'); 

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_1_10k',
	'JOIN1_DUP', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V1',
	'Join1, a(X,Y) Bench. [V1: Rel in Attr, no dupcheck] 10K*5');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_1_50k',
	'JOIN1_DUP', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V1',
	'Join1, a(X,Y) Bench. [V1: Rel in Attr, no dupcheck] 50K*5');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_1_250k',
	'JOIN1_DUP', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V1',
	'Join1, a(X,Y) Bench. [V1: Rel in Attr, no dupcheck] 250K*5');

-- j1axy_2_*:

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_2_test',
	'JOIN1_DUP', 0, 'd1000_test.P',
	'V2',
	'Join1, a(X,Y) Bench. [V2: RelAttr, no goto, no dupch] test'); 

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_2_10k',
	'JOIN1_DUP', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V2',
	'Join1, a(X,Y) Bench. [V2: RelAttr, no goto, no dupch] 10K*5');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_2_50k',
	'JOIN1_DUP', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V2',
	'Join1, a(X,Y) Bench. [V2: RelAttr, no goto, no dupch] 50K*5');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_2_250k',
	'JOIN1_DUP', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V2',
	'Join1, a(X,Y) Bench. [V2: RelAttr, no goto, no dupch] 250K*5');

-- j1axy_3_*:

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_3_test',
	'JOIN1_DUP', 0, 'd1000_test.P',
	'V3',
	'Join1, a(X,Y) Bench. [V3: Rel:LocalVar, static, NoDC] test'); 

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_3_10k',
	'JOIN1_DUP', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V3',
	'Join1, a(X,Y) Bench. [V3: Rel:LocalVar, static, NoDC] 10K*5');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_3_50k',
	'JOIN1_DUP', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V3',
	'Join1, a(X,Y) Bench. [V3: Rel:LocalVar, static, NoDC] 50K*5');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_3_250k',
	'JOIN1_DUP', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V3',
	'Join1, a(X,Y) Bench. [V3: Rel:LocalVar, static, NoDC] 250K*5');

-- j1axy_4_*
-- This does a duplicate check for b1, b2, c1.
-- The result is uncomparable, neither JOIN1_DUP, nor JOIN1.
-- We skip it here.

-- j1axy_5_* (same as V1 in bam):

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_5_test',
	'JOIN1', 0, 'd1000_test.P',
	'V5',
	'Join1, a(X,Y) [V5: RelAttr, -goto, fullDupCh] test');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_5_10k',
	'JOIN1', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V5',
	'Join1, a(X,Y) [V5: RelAttr, -goto, fullDupCh] 10K*5');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_5_50k',
	'JOIN1', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V5',
	'Join1, a(X,Y) [V5: RelAttr, -goto, fullDupCh] 50K*5');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_5_250k',
	'JOIN1', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V5',
	'Join1, a(X,Y) [V5: RelAttr, -goto, fullDupCh] 250K*5');

-- j1axy_6_* (same as V2 in bam):

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_6_test',
	'JOIN1', 0, 'd1000_test.P',
	'V6',
	'Join1, a(X,Y) [V6: no goto, bitmap-dupcheck], test');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_6_10k',
	'JOIN1', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V6',
	'Join1, a(X,Y) [V6: no goto, bitmap-dupcheck], 10K*5');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_6_50k',
	'JOIN1', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V6',
	'Join1, a(X,Y) [V6: no goto, bitmap-dupcheck], 50K*5');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_6_250k',
	'JOIN1', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V6',
	'Join1, a(X,Y) [V6: no goto, bitmap-dupcheck], 250K*5');

-- j1axy_7_* (same as V3 in bam):

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_7_test',
	'JOIN1', 0, 'd1000_test.P',
	'V7',
	'Join1, a(X,Y) [V7: goto, bitmap-dupC, cursor], test');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_7_10k',
	'JOIN1', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V7',
	'Join1, a(X,Y) [V7: goto, bitmap-dupC, cursor], 10K*5');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_7_50k',
	'JOIN1', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V7',
	'Join1, a(X,Y) [V7: goto, bitmap-dupC, cursor], 50K*5');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_7_250k',
	'JOIN1', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V7',
	'Join1, a(X,Y) [V7: goto, bitmap-dupC, cursor], 250K*5');

-- j1axy_8_* (same as V4 in bam):

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_8_test',
	'JOIN1', 0, 'd1000_test.P',
	'V8: Functions',
	'Join1, a(X,Y) [V8: functions, bitmap-dupC], test');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_8_10k',
	'JOIN1', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V8: Functions',
	'Join1, a(X,Y) [V8: functions, bitmap-dupC], 10K*5');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_8_50k',
	'JOIN1', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V8: Functions',
	'Join1, a(X,Y) [V8: functions, bitmap-dupC], 50K*5');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_8_250k',
	'JOIN1', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V8: Functions',
	'Join1, a(X,Y) [V8: functions, bitmap-dupC], 250K*5');

-- j1axy_9_* (same as V5 in bam):

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_9_test',
	'JOIN1', 0, 'd1000_test.P',
	'V9',
	'Join1, a(X,Y) [V9: fun without args, bitmap], test');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_9_10k',
	'JOIN1', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V9',
	'Join1, a(X,Y) [V9: fun without args, bitmap], 10K*5');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_9_50k',
	'JOIN1', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V9',
	'Join1, a(X,Y) [V9: fun without args, bitmap], 50K*5');

INSERT INTO TESTS VALUES (
	'ydb', 'j1axy_9_250k',
	'JOIN1', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V9',
	'Join1, a(X,Y) [V9: fun without args, bitmap], 250K*5');

-- ----------------------------------------------------------------------------
-- TCFF Tests for ydb:
-- ----------------------------------------------------------------------------

-- tcff_1_*:

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_1_test',
	'TCFF', 0, 'tc_test.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], Small Test File');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_1_f1',
	'TCFF', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_1_f2',
	'TCFF', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_1_f3',
	'TCFF', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_1_f4',
	'TCFF', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_1_f5',
	'TCFF', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_1_f6',
	'TCFF', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_1_f7',
	'TCFF', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_1_f8',
	'TCFF', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_1_f9',
	'TCFF', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_1_f10',
	'TCFF', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 10: 2k-1M-cyc');

-- tcff_2_*:

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_2_test',
	'TCFF', 0, 'tc_test.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], Small Test File');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_2_f1',
	'TCFF', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_2_f2',
	'TCFF', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_2_f3',
	'TCFF', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_2_f4',
	'TCFF', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_2_f5',
	'TCFF', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_2_f6',
	'TCFF', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_2_f7',
	'TCFF', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_2_f8',
	'TCFF', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_2_f9',
	'TCFF', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_2_f10',
	'TCFF', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface], File 10: 2k-1M-cyc');

-- tcff_3_*:

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_3_test',
	'TCFF', 0, 'tc_test.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], Small Test File');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_3_f1',
	'TCFF', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_3_f2',
	'TCFF', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_3_f3',
	'TCFF', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_3_f4',
	'TCFF', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_3_f5',
	'TCFF', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_3_f6',
	'TCFF', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_3_f7',
	'TCFF', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_3_f8',
	'TCFF', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_3_f9',
	'TCFF', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_3_f10',
	'TCFF', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V3: seminaive',
	'tc(X,Y) [V3: Seminaive Eval.], File 10: 2k-1M-cyc');

-- tcff_4_*:

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_4_test',
	'TCFF', 0, 'tc_test.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], Small Test File');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_4_f1',
	'TCFF', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_4_f2',
	'TCFF', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_4_f3',
	'TCFF', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_4_f4',
	'TCFF', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_4_f5',
	'TCFF', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_4_f6',
	'TCFF', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_4_f7',
	'TCFF', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_4_f8',
	'TCFF', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_4_f9',
	'TCFF', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcff_4_f10',
	'TCFF', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Functions], File 10: 2k-1M-cyc');

-- ----------------------------------------------------------------------------
-- TCBF Tests for ydb:
-- ----------------------------------------------------------------------------

-- tcbf_1_*:

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_1_test',
	'TCBF', 0, 'tc_test.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], Small Test File');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_1_f1',
	'TCBF', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_1_f2',
	'TCBF', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_1_f3',
	'TCBF', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_1_f4',
	'TCBF', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_1_f5',
	'TCBF', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_1_f6',
	'TCBF', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_1_f7',
	'TCBF', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_1_f8',
	'TCBF', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_1_f9',
	'TCBF', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_1_f10',
	'TCBF', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V1',
	'tc(X,Y) [V1: RelLocalVar], File 10: 2k-1M-cyc');

-- tcbf_2_*:

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_2_test',
	'TCBF', 0, 'tc_test.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface, RelAttr], Small Test File');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_2_f1',
	'TCBF', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface, RelAttr], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_2_f2',
	'TCBF', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface, RelAttr], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_2_f3',
	'TCBF', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface, RelAttr], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_2_f4',
	'TCBF', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface, RelAttr], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_2_f5',
	'TCBF', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface, RelAttr], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_2_f6',
	'TCBF', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface, RelAttr], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_2_f7',
	'TCBF', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface, RelAttr], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_2_f8',
	'TCBF', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface, RelAttr], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_2_f9',
	'TCBF', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface, RelAttr], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_2_f10',
	'TCBF', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V2: switch',
	'tc(X,Y) [V2: Cursor Interface, RelAttr], File 10: 2k-1M-cyc');

-- tcbf_3_*:
-- This is not yet implemented.
-- It should be seminaive evaluation.

-- tcbf_4_*:

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_4_test',
	'TCBF', 0, 'tc_test.P',
	'V4: functions',
	'tc(X,Y) [V4: Procedures], Small Test File');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_4_f1',
	'TCBF', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Procedures], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_4_f2',
	'TCBF', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Procedures], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_4_f3',
	'TCBF', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Procedures], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_4_f4',
	'TCBF', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Procedures], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_4_f5',
	'TCBF', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Procedures], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_4_f6',
	'TCBF', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Procedures], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_4_f7',
	'TCBF', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Procedures], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_4_f8',
	'TCBF', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Procedures], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_4_f9',
	'TCBF', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Procedures], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'ydb', 'tcbf_4_f10',
	'TCBF', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V4: functions',
	'tc(X,Y) [V4: Procedures], File 10: 2k-1M-cyc');

-- ----------------------------------------------------------------------------
-- Wine Ontology Test for ydb:
-- ----------------------------------------------------------------------------

-- wine:

INSERT INTO TESTS VALUES (
	'ydb', 'wine',
	'WINE', 1, 'wine_data.P',
	'V1',
	'Wine Ontology Benchmark');

-- ============================================================================
-- Old Tests for ydb (need to fix output before running these):
-- ============================================================================

-- ----------------------------------------------------------------------------
-- Data Loader Tests:
-- ----------------------------------------------------------------------------

INSERT INTO TESTS VALUES (
	'ydb', 'LoadDBLP',
	'LOAD_DBLP', 1, 'dblp.data',
	'V1: Handcrafted Loader',
	'Load DBLP data file (with hand-crafted loader)');

INSERT INTO TESTS VALUES (
	'ydb', 'LoadTC',
	'LOAD_TC', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V1: Handcrafted Loader',
	'transitive closure data file (with handcrafted loader)');

INSERT INTO TESTS VALUES (
	'ydb', 'LoadTCGen',
	'LOAD_TC', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V2: General Loader',
	'transitive closure data file (with general loader)');

-- ----------------------------------------------------------------------------
-- Set Implementation Tests for ydb (One Column):
-- ----------------------------------------------------------------------------

-- set_1e_*:

INSERT INTO TESTS VALUES (
	'ydb', 'set_1e_test',
	'SET1', 1, '1col_10_rows_seq',
	'V1: extendible hashtab',
	'Set with 1 column, extendible Hash table, 10 rows seq.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_1e_M',
	'SET1', 2, '1col_1M_rows_seq',
	'V1: extendible hashtab',
	'Set with 1 column, extendible Hash table, 1 mio rows seq.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_1e_M2',
	'SET1', 3, '1col_1M_rows_mix',
	'V1: extendible hashtab',
	'Set with 1 column, extendible Hash table, 1 mio rows mix.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_1e_H',
	'SET1', 4, '1col_100M_rows_mix',
	'V1: extendible hashtab',
	'Set with 1 column, extendible Hash table, 100 mio rows mix.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_1e_G',
	'SET1', 5, '1col_1G_rows_mix',
	'V1: extendible hashtab',
	'Set with 1 column, extendible Hash table, 1 billion rows');

-- set_1d_*:

INSERT INTO TESTS VALUES (
	'ydb', 'set_1d_test',
	'SET1', 1, '1col_10_rows_seq',
	'V2: dynamic hashtab',
	'Set with 1 column, dynamic Hash table, 10 rows seq.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_1d_M',
	'SET1', 2, '1col_1M_rows_seq',
	'V2: dynamic hashtab',
	'Set with 1 column, dynamic Hash table, 1 mio rows seq.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_1d_M2',
	'SET1', 3, '1col_1M_rows_mix',
	'V2: dynamic hashtab',
	'Set with 1 column, dynamic Hash table, 1 mio rows mix.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_1d_H',
	'SET1', 4, '1col_100M_rows_mix',
	'V2: dynamic hashtab',
	'Set with 1 column, dynamic Hash table, 100 mio rows mix.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_1d_G',
	'SET1', 5, '1col_1G_rows_mix',
	'V2: dynamic hashtab',
	'Set with 1 column, dynamic Hash table, 1 billion rows');

-- set_1s_*:

INSERT INTO TESTS VALUES (
	'ydb', 'set_1s_test',
	'SET1', 1, '1col_10_rows_seq',
	'V3: standard library',
	'Set with 1 column, standard library, 10 rows seq.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_1s_M',
	'SET1', 2, '1col_1M_rows_seq',
	'V3: standard library',
	'Set with 1 column, standard library, 1 mio rows seq.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_1s_M2',
	'SET1', 3, '1col_1M_rows_mix',
	'V3: standard library',
	'Set with 1 column, standard library, 1 mio rows mix.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_1s_H',
	'SET1', 4, '1col_100M_rows_mix',
	'V3: standard library',
	'Set with 1 column, standard library, 100 mio rows mix.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_1s_G',
	'SET1', 5, '1col_1G_rows_mix',
	'V3: standard library',
	'Set with 1 column, standard library, 1 billion rows');

-- ----------------------------------------------------------------------------
-- Set Implementation Tests for ydb (Two Columns):
-- ----------------------------------------------------------------------------

-- set_2e_*:

INSERT INTO TESTS VALUES (
	'ydb', 'set_2e_test',
	'SET2', 6, '2col_10_rows_seq',
	'V1: extendible hashtab',
	'Set with 2 columns, extendible Hash table, 10 rows seq.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_2e_M',
	'SET2', 7, '2col_1M_rows_seq',
	'V1: extendible hashtab',
	'Set with 2 columns, extendible Hash table, 1 mio rows seq.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_2e_M2',
	'SET2', 8, '2col_1M_rows_mix',
	'V1: extendible hashtab',
	'Set with 2 columns, extendible Hash table, 1 mio rows mix.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_2e_H',
	'SET2', 9, '2col_100M_rows_mix',
	'V1: extendible hashtab',
	'Set with 2 columns, extendible Hash table, 100 mio rows');

INSERT INTO TESTS VALUES (
	'ydb', 'set_2e_G',
	'SET2', 10, '2col_1G_rows_mix',
	'V1: extendible hashtab',
	'Set with 2 columns, extendible Hash table, 1 billion rows');

-- set_2d_*:

INSERT INTO TESTS VALUES (
	'ydb', 'set_2d_test',
	'SET2', 6, '2col_10_rows_seq',
	'V2: dynamic hashtab',
	'Set with 2 columns, dynamic Hash table, 10 rows seq.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_2d_M',
	'SET2', 7, '2col_1M_rows_seq',
	'V2: dynamic hashtab',
	'Set with 2 columns, dynamic Hash table, 1 mio rows seq.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_2d_M2',
	'SET2', 8, '2col_1M_rows_mix',
	'V2: dynamic hashtab',
	'Set with 2 columns, dynamic Hash table, 1 mio rows mix.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_2d_H',
	'SET2', 9, '2col_100M_rows_mix',
	'V2: dynamic hashtab',
	'Set with 2 columns, dynamic Hash table, 100 mio rows');

INSERT INTO TESTS VALUES (
	'ydb', 'set_2d_G',
	'SET2', 10, '2col_1G_rows_mix',
	'V2: dynamic hashtab',
	'Set with 2 columns, dynamic Hash table, 1 billion rows');

-- set_2s_*:

INSERT INTO TESTS VALUES (
	'ydb', 'set_2s_test',
	'SET2', 6, '2col_10_rows_seq',
	'V3: standard library',
	'Set with 2 columns, standard library, 10 rows seq.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_2s_M',
	'SET2', 7, '2col_1M_rows_seq',
	'V3: standard library',
	'Set with 2 columns, standard library, 1 mio rows seq.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_2s_M2',
	'SET2', 8, '2col_1M_rows_mix',
	'V3: standard library',
	'Set with 2 columns, standard library, 1 mio rows mix.');

INSERT INTO TESTS VALUES (
	'ydb', 'set_2s_H',
	'SET2', 9, '2col_100M_rows_mix',
	'V3: standard library',
	'Set with 2 columns, standard library, 100 mio rows');

INSERT INTO TESTS VALUES (
	'ydb', 'set_2s_G',
	'SET2', 10, '2col_1G_rows_mix',
	'V3: standard library',
	'Set with 2 columns, standard library, 1 billion rows');

-- ============================================================================
-- Tests for XSB:
-- ============================================================================

-- ----------------------------------------------------------------------------
-- DBLP Tests for XSB:
-- ----------------------------------------------------------------------------

-- dblp_dyn_*:

INSERT INTO TESTS VALUES (
	'xsb', 'dblp_dyn_std',
	'DBLP', 1, 'dblp.data',
	'load_dyn',
	'load_dyn, no index, standard data file (122 MB, 2.4M rows)');

INSERT INTO TESTS VALUES (
	'xsb', 'dblp_dyn_big',
	'DBLP', 2, 'dblp_big.data',
	'load_dyn',
	'load_dyn, no index, big data file (3 GB, 50M rows)');

-- dblp_dync_*:

INSERT INTO TESTS VALUES (
	'xsb', 'dblp_dync_std',
	'DBLP', 1, 'dblp.data',
	'load_dync',
	'load_dync, no index, standard data file (122 MB, 2.4M rows)');

INSERT INTO TESTS VALUES (
	'xsb', 'dblp_dync_big',
	'DBLP', 2, 'dblp_big.data',
	'load_dync',
	'load_dync, no index, big data file (3 GB, 50M rows)');

-- dblp_dynin_*:

INSERT INTO TESTS VALUES (
	'xsb', 'dblp_dynin_std',
	'DBLP', 1, 'dblp.data',
	'load_dyn, index1+2',
	'load_dyn, index on col 1+2, standard data file (122 MB, 2.4M rows)');

INSERT INTO TESTS VALUES (
	'xsb', 'dblp_dynin_big',
	'DBLP', 2, 'dblp_big.data',
	'load_dyn, index1+2',
	'load_dyn, index on col 1+2, big data file (3 GB, 50M rows)');

-- dblp_dyncin_*:

INSERT INTO TESTS VALUES (
	'xsb', 'dblp_dyncin_std',
	'DBLP', 1, 'dblp.data',
	'load_dync, index1+2',
	'load_dync, index on col 1+2, standard data file (122 MB, 2.4M rows)');

INSERT INTO TESTS VALUES (
	'xsb', 'dblp_dyncin_big',
	'DBLP', 2, 'dblp_big.data',
	'load_dync, index1+2',
	'load_dync, index on col 1+2, big data file (3 GB, 50M rows)');

-- dblp_dyntr_*:

INSERT INTO TESTS VALUES (
	'xsb', 'dblp_dyntr_std',
	'DBLP', 1, 'dblp.data',
	'load_dyn, trie index',
	'load_dyn, trie index, standard data file (122 MB, 2.4M rows)');

INSERT INTO TESTS VALUES (
	'xsb', 'dblp_dyntr_big',
	'DBLP', 2, 'dblp_big.data',
	'load_dyn, trie index',
	'load_dyn, trie index, big data file (3 GB, 50M rows)');

-- dblp_dynctr_*:

INSERT INTO TESTS VALUES (
	'xsb', 'dblp_dynctr_std',
	'DBLP', 1, 'dblp.data',
	'load_dync, trie index',
	'load_dync, trie index, standard data file (122 MB, 2.4M rows)');

INSERT INTO TESTS VALUES (
	'xsb', 'dblp_dynctr_big',
	'DBLP', 2, 'dblp_big.data',
	'load_dync, trie index',
	'load_dync, trie index, big data file (3 GB, 50M rows)');

-- ----------------------------------------------------------------------------
-- Join1 Tests for XSB:
-- ----------------------------------------------------------------------------

-- j1axy_none_*:

INSERT INTO TESTS VALUES (
	'xsb', 'j1axy_none_10k',
	'JOIN1_DUP', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V0: no tabling',
	'Join1 with duplicates, a(X,Y) [V0: no tabling], 10K*5');

INSERT INTO TESTS VALUES (
	'xsb', 'j1axy_none_50k',
	'JOIN1_DUP', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V0: no tabling',
	'Join1 with duplicates, a(X,Y) [V0: no tabling], 50K*5');

INSERT INTO TESTS VALUES (
	'xsb', 'j1axy_none_250k',
	'JOIN1_DUP', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V0: no tabling',
	'Join1 with duplicates, a(X,Y) [V0: no tabling], 250K*5');

-- j1axy_a_*:

INSERT INTO TESTS VALUES (
	'xsb', 'j1axy_a_10k',
	'JOIN1', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V1: only a tabled',
	'Join1, a(X,Y) [V1: only a tabled], 10K*5');

INSERT INTO TESTS VALUES (
	'xsb', 'j1axy_a_50k',
	'JOIN1', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V1: only a tabled',
	'Join1, a(X,Y) [V1: only a tabled], 50K*5');

INSERT INTO TESTS VALUES (
	'xsb', 'j1axy_a_250k',
	'JOIN1', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V1: only a tabled',
	'Join1, a(X,Y) [V1: only a tabled], 250K*5');

-- j1axy_all_*:

INSERT INTO TESTS VALUES (
	'xsb', 'j1axy_all_10k',
	'JOIN1', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V2: all derived preds tabled',
	'Join1, a(X,Y) [V2: all derived preds tabled (subsumptive)], 10K*5');

INSERT INTO TESTS VALUES (
	'xsb', 'j1axy_all_50k',
	'JOIN1', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V2: all derived preds tabled',
	'Join1, a(X,Y) [V2: all derived preds tabled (subsumptive)], 50K*5');

INSERT INTO TESTS VALUES (
	'xsb', 'j1axy_all_250k',
	'JOIN1', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V2: all derived preds tabled',
	'Join1, a(X,Y) [V2: all derived preds tabled (subsumptive)], 250K*5');

-- j1axy_allv_*:

INSERT INTO TESTS VALUES (
	'xsb', 'j1axy_allv_10k',
	'JOIN1', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V4: all derived preds variant tabled',
	'Join1, a(X,Y) [V4: all derived preds tabled, variant tab], 10K*5');

INSERT INTO TESTS VALUES (
	'xsb', 'j1axy_allv_50k',
	'JOIN1', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V4: all derived preds variant tabled',
	'Join1, a(X,Y) [V2: all derived preds tabled, variant tab], 50K*5');

INSERT INTO TESTS VALUES (
	'xsb', 'j1axy_allv_250k',
	'JOIN1', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V4: all derived preds variant tabled',
	'Join1, a(X,Y) [V2: all derived preds tabled, variant tab], 250K*5');

-- j1axy_alli_*:

INSERT INTO TESTS VALUES (
	'xsb', 'j1axy_alli_10k',
	'JOIN1', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V4: all derived preds tabled, index',
	'Join1, a(X,Y) [V4: all derived preds tabled, with indexes], 10K*5');

INSERT INTO TESTS VALUES (
	'xsb', 'j1axy_alli_50k',
	'JOIN1', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V4: all derived preds tabled, index',
	'Join1, a(X,Y) [V4: all derived preds tabled, with indexes], 50K*5');

INSERT INTO TESTS VALUES (
	'xsb', 'j1axy_alli_250k',
	'JOIN1', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V4: all derived preds tabled, index',
	'Join1, a(X,Y) [V4: all derived preds tabled, with indexes], 250K*5');

-- j1axy_allt_*:

INSERT INTO TESTS VALUES (
	'xsb', 'j1axy_allt_10k',
	'JOIN1', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V5: all derived preds tabled, trie',
	'Join1, a(X,Y) [V5: all derived preds tabled, with trie ind], 10K*5');

INSERT INTO TESTS VALUES (
	'xsb', 'j1axy_allt_50k',
	'JOIN1', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V5: all derived preds tabled, trie',
	'Join1, a(X,Y) [V5: all derived preds tabled, with trie ind], 50K*5');

INSERT INTO TESTS VALUES (
	'xsb', 'j1axy_allt_250k',
	'JOIN1', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V5: all derived preds tabled, trie',
	'Join1, a(X,Y) [V5: all derived preds tabled, with trie ind], 250K*5');

-- ----------------------------------------------------------------------------
-- TCFF Tests for XSB:
-- ----------------------------------------------------------------------------

-- tcff_dyn_*:

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dyn_f1',
	'TCFF', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V1: load_dyn',
	'tc(X,Y) [V1: load_dyn, trie-index for par], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dyn_f2',
	'TCFF', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V1: load_dyn',
	'tc(X,Y) [V1: load_dyn, trie-index for par], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dyn_f3',
	'TCFF', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V1: load_dyn',
	'tc(X,Y) [V1: load_dyn, trie-index for par], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dyn_f4',
	'TCFF', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V1: load_dyn',
	'tc(X,Y) [V1: load_dyn, trie-index for par], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dyn_f5',
	'TCFF', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V1: load_dyn',
	'tc(X,Y) [V1: load_dyn, trie-index for par], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dyn_f6',
	'TCFF', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V1: load_dyn',
	'tc(X,Y) [V1: load_dyn, trie-index for par], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dyn_f7',
	'TCFF', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V1: load_dyn',
	'tc(X,Y) [V1: load_dyn, trie-index for par], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dyn_f8',
	'TCFF', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V1: load_dyn',
	'tc(X,Y) [V1: load_dyn, trie-index for par], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dyn_f9',
	'TCFF', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V1: load_dyn',
	'tc(X,Y) [V1: load_dyn, trie-index for par], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dyn_f10',
	'TCFF', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V1: load_dyn',
	'tc(X,Y) [V1: load_dyn, trie-index for par], File 10: 2k-1M-cyc');

-- tcff_dync_*:

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dync_f1',
	'TCFF', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V1: load_dync',
	'tc(X,Y) [V1: load_dync, trie-index for par], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dync_f2',
	'TCFF', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V1: load_dync',
	'tc(X,Y) [V1: load_dync, trie-index for par], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dync_f3',
	'TCFF', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V1: load_dync',
	'tc(X,Y) [V1: load_dync, trie-index for par], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dync_f4',
	'TCFF', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V1: load_dync',
	'tc(X,Y) [V1: load_dync, trie-index for par], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dync_f5',
	'TCFF', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V1: load_dync',
	'tc(X,Y) [V1: load_dync, trie-index for par], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dync_f6',
	'TCFF', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V1: load_dync',
	'tc(X,Y) [V1: load_dync, trie-index for par], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dync_f7',
	'TCFF', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V1: load_dync',
	'tc(X,Y) [V1: load_dync, trie-index for par], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dync_f8',
	'TCFF', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V1: load_dync',
	'tc(X,Y) [V1: load_dync, trie-index for par], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dync_f9',
	'TCFF', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V1: load_dync',
	'tc(X,Y) [V1: load_dync, trie-index for par], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcff_dync_f10',
	'TCFF', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V1: load_dync',
	'tc(X,Y) [V1: load_dync, trie-index for par], File 10: 2k-1M-cyc');

-- ----------------------------------------------------------------------------
-- TCBF Tests for XSB:
-- ----------------------------------------------------------------------------

-- tcbf_dyn_*:

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dyn_f1',
	'TCBF', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V1: load_dyn',
	'tc(1,X) [V1: load_dyn, trie-index for par], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dyn_f2',
	'TCBF', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V1: load_dyn',
	'tc(1,X) [V1: load_dyn, trie-index for par], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dyn_f3',
	'TCBF', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V1: load_dyn',
	'tc(1,X) [V1: load_dyn, trie-index for par], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dyn_f4',
	'TCBF', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V1: load_dyn',
	'tc(1,X) [V1: load_dyn, trie-index for par], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dyn_f5',
	'TCBF', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V1: load_dyn',
	'tc(1,X) [V1: load_dyn, trie-index for par], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dyn_f6',
	'TCBF', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V1: load_dyn',
	'tc(1,X) [V1: load_dyn, trie-index for par], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dyn_f7',
	'TCBF', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V1: load_dyn',
	'tc(1,X) [V1: load_dyn, trie-index for par], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dyn_f8',
	'TCBF', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V1: load_dyn',
	'tc(1,X) [V1: load_dyn, trie-index for par], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dyn_f9',
	'TCBF', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V1: load_dyn',
	'tc(1,X) [V1: load_dyn, trie-index for par], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dyn_f10',
	'TCBF', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V1: load_dyn',
	'tc(1,X) [V1: load_dyn, trie-index for par], File 10: 2k-1M-cyc');

-- tcbf_dync_*:

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dync_f1',
	'TCBF', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V2: load_dync',
	'tc(1,X) [V2: load_dync, trie-index for par], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dync_f2',
	'TCBF', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V2: load_dync',
	'tc(1,X) [V2: load_dync, trie-index for par], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dync_f3',
	'TCBF', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V2: load_dync',
	'tc(1,X) [V2: load_dync, trie-index for par], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dync_f4',
	'TCBF', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V2: load_dync',
	'tc(1,X) [V2: load_dync, trie-index for par], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dync_f5',
	'TCBF', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V2: load_dync',
	'tc(1,X) [V2: load_dync, trie-index for par], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dync_f6',
	'TCBF', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V2: load_dync',
	'tc(1,X) [V2: load_dync, trie-index for par], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dync_f7',
	'TCBF', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V2: load_dync',
	'tc(1,X) [V2: load_dync, trie-index for par], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dync_f8',
	'TCBF', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V2: load_dync',
	'tc(1,X) [V2: load_dync, trie-index for par], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dync_f9',
	'TCBF', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V2: load_dync',
	'tc(1,X) [V2: load_dync, trie-index for par], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_dync_f10',
	'TCBF', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V2: load_dync',
	'tc(1,X) [V2: load_dync, trie-index for par], File 10: 2k-1M-cyc');

-- tcbf_sldmdc_*:

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_sldmdc_f1',
	'TCBF_SLDMAGIC', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V3: SLDMagic, load_dync',
	'tc(1,X) [V3: SLDMagic, load_dync, trie-index], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_sldmdc_f2',
	'TCBF_SLDMAGIC', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V3: SLDMagic, load_dync',
	'tc(1,X) [V3: SLDMagic, load_dync, trie-index], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_sldmdc_f3',
	'TCBF_SLDMAGIC', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V3: SLDMagic, load_dync',
	'tc(1,X) [V3: SLDMagic, load_dync, trie-index], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_sldmdc_f4',
	'TCBF_SLDMAGIC', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V3: SLDMagic, load_dync',
	'tc(1,X) [V3: SLDMagic, load_dync, trie-index], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_sldmdc_f5',
	'TCBF_SLDMAGIC', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V3: SLDMagic, load_dync',
	'tc(1,X) [V3: SLDMagic, load_dync, trie-index], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_sldmdc_f6',
	'TCBF_SLDMAGIC', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V3: SLDMagic, load_dync',
	'tc(1,X) [V3: SLDMagic, load_dync, trie-index], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_sldmdc_f7',
	'TCBF_SLDMAGIC', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V3: SLDMagic, load_dync',
	'tc(1,X) [V3: SLDMagic, load_dync, trie-index], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_sldmdc_f8',
	'TCBF_SLDMAGIC', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V3: SLDMagic, load_dync',
	'tc(1,X) [V3: SLDMagic, load_dync, trie-index], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_sldmdc_f9',
	'TCBF_SLDMAGIC', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V3: SLDMagic, load_dync',
	'tc(1,X) [V3: SLDMagic, load_dync, trie-index], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'xsb', 'tcbf_sldmdc_f10',
	'TCBF_SLDMAGIC', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V3: SLDMagic, load_dync',
	'tc(1,X) [V3: SLDMagic, load_dync, trie-index], File 10: 2k-1M-cyc');

-- ----------------------------------------------------------------------------
-- Wine Ontology Test for XSB:
-- ----------------------------------------------------------------------------

-- wine_idx_sub:

INSERT INTO TESTS VALUES (
	'xsb', 'wine_idx_sub',
	'WINE', 1, 'wine_data.P',
	'V1: load_dync, subsumptive tab., indexes',
	'wine ontology [V1: load_dync, subsumptive tabling, std. indexes]');


-- ============================================================================
-- Tests for YAP:
-- ============================================================================

-- ----------------------------------------------------------------------------
-- DBLP Tests for YAP:
-- ----------------------------------------------------------------------------

-- dblp_*:

INSERT INTO TESTS VALUES (
	'yap', 'dblp_bench',
	'DBLP', 1, 'dblp.data',
	'',
	'DBLP Benchmark, standard data file (122 MB, 2.4M rows)');

INSERT INTO TESTS VALUES (
	'yap', 'dblp_big',
	'DBLP', 2, 'dblp_big.data',
	'',
	'DBLP Benchmark, big data file (3 GB, 50M rows)');

-- ----------------------------------------------------------------------------
-- Join1 Tests for YAP:
-- ----------------------------------------------------------------------------

-- j1axy_none_*:

INSERT INTO TESTS VALUES (
	'yap', 'j1axy_none_10k',
	'JOIN1_DUP', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V0: no tabling',
	'Join1 with duplicates, a(X,Y) [V0: no tabling], 10K*5');

INSERT INTO TESTS VALUES (
	'yap', 'j1axy_none_50k',
	'JOIN1_DUP', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V0: no tabling',
	'Join1 with duplicates, a(X,Y) [V0: no tabling], 50K*5');

INSERT INTO TESTS VALUES (
	'yap', 'j1axy_none_250k',
	'JOIN1_DUP', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V0: no tabling',
	'Join1 with duplicates, a(X,Y) [V0: no tabling], 250K*5');

-- j1axy_a_*:

INSERT INTO TESTS VALUES (
	'yap', 'j1axy_a_10k',
	'JOIN1', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V1: only a tabled',
	'Join1, a(X,Y) [V1: only a tabled], 10K*5');

INSERT INTO TESTS VALUES (
	'yap', 'j1axy_a_50k',
	'JOIN1', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V1: only a tabled',
	'Join1, a(X,Y) [V1: only a tabled], 50K*5');

INSERT INTO TESTS VALUES (
	'yap', 'j1axy_a_250k',
	'JOIN1', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V1: only a tabled',
	'Join1, a(X,Y) [V1: only a tabled], 250K*5');

-- j1axy_all_*:

INSERT INTO TESTS VALUES (
	'yap', 'j1axy_all_10k',
	'JOIN1', 1, 'd1000_relsize10000_xsb_cyc.P',
	'V2: all derived preds tabled',
	'Join1, a(X,Y) [V2: all derived preds tabled], 10K*5');

INSERT INTO TESTS VALUES (
	'yap', 'j1axy_all_50k',
	'JOIN1', 2, 'd1000_relsize50000_xsb_cyc.P',
	'V2: all derived preds tabled',
	'Join1, a(X,Y) [V2: all derived preds tabled], 50K*5');

INSERT INTO TESTS VALUES (
	'yap', 'j1axy_all_250k',
	'JOIN1', 3, 'd1000_relsize250000_xsb_cyc.P',
	'V2: all derived preds tabled',
	'Join1, a(X,Y) [V2: all derived preds tabled], 250K*5');


-- ----------------------------------------------------------------------------
-- TCFF Tests for YAP:
-- ----------------------------------------------------------------------------

-- tcff_tab_*:

INSERT INTO TESTS VALUES (
	'yap', 'tcff_tab_f1',
	'TCFF', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcff_tab_f2',
	'TCFF', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcff_tab_f3',
	'TCFF', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcff_tab_f4',
	'TCFF', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcff_tab_f5',
	'TCFF', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcff_tab_f6',
	'TCFF', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcff_tab_f7',
	'TCFF', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcff_tab_f8',
	'TCFF', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcff_tab_f9',
	'TCFF', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcff_tab_f10',
	'TCFF', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 10: 2k-1M-cyc');


-- ----------------------------------------------------------------------------
-- TBFF Tests for YAP:
-- ----------------------------------------------------------------------------

-- tcbf_tab_*:

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_tab_f1',
	'TCBF', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_tab_f2',
	'TCBF', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_tab_f3',
	'TCBF', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_tab_f4',
	'TCBF', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_tab_f5',
	'TCBF', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_tab_f6',
	'TCBF', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_tab_f7',
	'TCBF', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_tab_f8',
	'TCBF', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_tab_f9',
	'TCBF', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_tab_f10',
	'TCBF', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V1: normal',
	'tc(1,X) [V1: tc tabled], File 10: 2k-1M-cyc');


-- tcbf_sldmdc_*:

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_sldmag_f1',
	'TCBF_SLDMAGIC', 1, 'tc_d1000_parsize50000_xsb_nocyc.P',
	'V2: with SLDMagic',
	'tc(1,X) [V2: with SLDMagic, all preds tabled], File 1: 50K-nocyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_sldmag_f2',
	'TCBF_SLDMAGIC', 2, 'tc_d1000_parsize50000_xsb_cyc.P',
	'V2: with SLDMagic',
	'tc(1,X) [V2: with SLDMagic, all preds tabled], File 2: 50K-cyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_sldmag_f3',
	'TCBF_SLDMAGIC', 3, 'tc_d1000_parsize250000_xsb_nocyc.P',
	'V2: with SLDMagic',
	'tc(1,X) [V2: with SLDMagic, all preds tabled], File 3: 250K-nocyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_sldmag_f4',
	'TCBF_SLDMAGIC', 4, 'tc_d1000_parsize250000_xsb_cyc.P',
	'V2: with SLDMagic',
	'tc(1,X) [V2: with SLDMagic, all preds tabled], File 4: 250K-cyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_sldmag_f5',
	'TCBF_SLDMAGIC', 5, 'tc_d1000_parsize500000_xsb_nocyc.P',
	'V2: with SLDMagic',
	'tc(1,X) [V2: with SLDMagic, all preds tabled], File 5: 500K-nocyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_sldmag_f6',
	'TCBF_SLDMAGIC', 6, 'tc_d1000_parsize500000_xsb_cyc.P',
	'V2: with SLDMagic',
	'tc(1,X) [V2: with SLDMagic, all preds tabled], File 6: 500K-cyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_sldmag_f7',
	'TCBF_SLDMAGIC', 7, 'tc_d2000_parsize500000_xsb_nocyc.P',
	'V2: with SLDMagic',
	'tc(1,X) [V2: with SLDMagic, all preds tabled], File 7: 2k-500K-nocyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_sldmag_f8',
	'TCBF_SLDMAGIC', 8, 'tc_d2000_parsize500000_xsb_cyc.P',
	'V2: with SLDMagic',
	'tc(1,X) [V2: with SLDMagic, all preds tabled], File 8: 2k-500K-cyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_sldmag_f9',
	'TCBF_SLDMAGIC', 9, 'tc_d2000_parsize1000000_xsb_nocyc.P',
	'V2: with SLDMagic',
	'tc(1,X) [V2: with SLDMagic, all preds tabled], File 9: 2k-1M-nocyc');

INSERT INTO TESTS VALUES (
	'yap', 'tcbf_sldmag_f10',
	'TCBF_SLDMAGIC', 10, 'tc_d2000_parsize1000000_xsb_cyc.P',
	'V2: with SLDMagic',
	'tc(1,X) [V2: with SLDMagic, all preds tabled], File 10: 2k-1M-cyc');

-- ----------------------------------------------------------------------------
-- Wine Ontology Test for YAP:
-- ----------------------------------------------------------------------------

-- wine_idx_sub:

INSERT INTO TESTS VALUES (
	'yap', 'wine_table',
	'WINE', 1, 'wine_data.P',
	'V1: table derived preds, reorder body',
	'wine ontology [V1: table 225 derived preds, reorder body lits var->]');


-- ============================================================================
-- Table for Results of Benchmark Runs (Test Runs):
-- ============================================================================


CREATE TABLE RUNS(
	RUN_DATE    DATE         NOT NULL,
	RUN_NO      NUMERIC(4)   NOT NULL,
	PROG        VARCHAR(20)  NOT NULL,
	VER         NUMERIC(4)   NOT NULL,
	MACHINE     VARCHAR(20)  NOT NULL,
	BENCH_ID    VARCHAR(20)  NOT NULL,
	LOAD_TIME   NUMERIC(8,3) NULL,
	EXEC_TIME   NUMERIC(8,3) NULL,
	TOTAL_TIME  NUMERIC(8,3) NULL,
	USER_TIME   NUMERIC(8,3) NULL,
	SYS_TIME    NUMERIC(8,3) NULL,
	REAL_TIME   NUMERIC(8,3) NOT NULL,
	MEM         NUMERIC(8,3) NULL,
	STATUS      VARCHAR(80)  NULL,
	REMARK      VARCHAR(800) NULL,
        CONSTRAINT  RUN_NO_POSITIVE
		CHECK(RUN_NO > 0),
        CONSTRAINT  LOAD_TIME_NONNEGATIVE
		CHECK(LOAD_TIME >= 0),
        CONSTRAINT  EXEC_TIME_NONNEGATIVE
		CHECK(EXEC_TIME >= 0),
        CONSTRAINT  TOTAL_TIME_NONNEGATIVE
		CHECK(TOTAL_TIME >= 0),
        CONSTRAINT  USER_TIME_NONNEGATIVE
		CHECK(USER_TIME >= 0),
        CONSTRAINT  SYS_TIME_NONNEGATIVE
		CHECK(SYS_TIME >= 0),
        CONSTRAINT  REAL_TIME_NONNEGATIVE
		CHECK(REAL_TIME >= 0),
        CONSTRAINT  MEM_NONNEGATIVE
		CHECK(MEM >= 0),
        CONSTRAINT  RUNS_PK
		PRIMARY KEY(RUN_DATE,RUN_NO,MACHINE,PROG,VER),
        CONSTRAINT  RUNS_REF_TESTS
		FOREIGN KEY(PROG, BENCH_ID) REFERENCES TESTS,
	CONSTRAINT  RUNS_REF_PROG_VER
		FOREIGN KEY(PROG, VER, MACHINE) REFERENCES PROG_VER);

-- ============================================================================
-- Full Statistical Evaluation of Run Data:
-- ============================================================================

CREATE VIEW RUN_STATISTICS AS
SELECT BENCH_ID, MACHINE, PROG, VER,
	ROUND(AVG(LOAD_TIME),3) AS AVG_LOAD_TIME,
	MIN(LOAD_TIME) AS MIN_LOAD_TIME,
	MAX(LOAD_TIME) AS MAX_LOAD_TIME,
	MAX(LOAD_TIME)-MIN(LOAD_TIME) AS DIFF_LOAD_TIME,
	ROUND(AVG(EXEC_TIME),3) AS AVG_EXEC_TIME,
	MIN(EXEC_TIME) AS MIN_EXEC_TIME,
	MAX(EXEC_TIME) AS MAX_EXEC_TIME,
	MAX(EXEC_TIME)-MIN(EXEC_TIME) AS DIFF_EXEC_TIME,
	ROUND(AVG(TOTAL_TIME),3) AS AVG_TOTAL_TIME,
	MIN(TOTAL_TIME) AS MIN_TOTAL_TIME,
	MAX(TOTAL_TIME) AS MAX_TOTAL_TIME,
	MAX(TOTAL_TIME)-MIN(TOTAL_TIME) AS DIFF_TOTAL_TIME,
	ROUND(AVG(USER_TIME),3) AS AVG_USER_TIME,
	MIN(USER_TIME) AS MIN_USER_TIME,
	MAX(USER_TIME) AS MAX_USER_TIME,
	MAX(USER_TIME)-MIN(USER_TIME) AS DIFF_USER_TIME,
	ROUND(AVG(SYS_TIME),3) AS AVG_SYS_TIME,
	MIN(SYS_TIME) AS MIN_SYS_TIME,
	MAX(SYS_TIME) AS MAX_SYS_TIME,
	MAX(SYS_TIME)-MIN(SYS_TIME) AS DIFF_SYS_TIME,
	ROUND(AVG(REAL_TIME),3) AS AVG_REAL_TIME,
	MIN(REAL_TIME) AS MIN_REAL_TIME,
	MAX(REAL_TIME) AS MAX_REAL_TIME,
	MAX(REAL_TIME)-MIN(REAL_TIME) AS DIFF_REAL_TIME,
	ROUND(AVG(MEM),3) AS AVG_MEM,
	MIN(MEM) AS MIN_MEM,
	MAX(MEM) AS MAX_MEM,
	MAX(MEM)-MIN(MEM) AS DIFF_MEM,
	COUNT(*) AS NUM_RUNS
FROM RUNS
GROUP BY BENCH_ID, MACHINE, PROG, VER
ORDER BY BENCH_ID, MACHINE, PROG, VER;


-- ============================================================================
-- Best Option Settings (in REAL_TIME) for a Program for a Benchmark:
-- ============================================================================

CREATE VIEW BEST_OPT AS
SELECT	B.BENCHMARK AS BENCH,
	T.INPUT_NO AS INPUT,
	T.OPTIONS, R.MACHINE, R.PROG, R.VER,
	R.AVG_REAL_TIME AS REAL_S
FROM	BENCHMARKS B, TESTS T, RUN_STATISTICS R
WHERE	B.BENCHMARK = T.BENCHMARK
AND	T.BENCH_ID = R.BENCH_ID
AND	T.PROG = R.PROG
AND NOT EXISTS(SELECT * FROM TESTS T2, RUN_STATISTICS R2
		WHERE R2.BENCH_ID = T2.BENCH_ID AND R2.PROG = T2.PROG
		AND   T2.BENCHMARK = T.BENCHMARK AND T2.INPUT_NO = T.INPUT_NO
		AND   R2.PROG = R.PROG AND R2.MACHINE = R.MACHINE
		AND   R2.AVG_REAL_TIME < R.AVG_REAL_TIME)
-- Eliminate trivial tests with run time 0: All options are best.
AND EXISTS(SELECT * FROM TESTS T3, RUN_STATISTICS R3
		WHERE R3.BENCH_ID = T3.BENCH_ID AND R3.PROG = T3.PROG
		AND   T3.BENCHMARK = T.BENCHMARK AND T3.INPUT_NO = T.INPUT_NO
		AND   R3.PROG = R.PROG AND R3.MACHINE = R.MACHINE
		AND   R3.AVG_REAL_TIME > 0)
ORDER BY B.SEQ_NO, T.INPUT_NO;

-- ============================================================================
-- Benchmark Results on Machine "bach":
-- ============================================================================

CREATE VIEW BACH_RESULTS AS
SELECT R.BENCH_ID AS BENCH,
	R.PROG AS PROG,
	R.AVG_LOAD_TIME AS LOAD_S,
	R.AVG_EXEC_TIME AS EXEC_S,
	R.AVG_TOTAL_TIME AS TOTAL_S,
	R.AVG_REAL_TIME AS REAL_S,
	R.AVG_MEM AS MEM_MB
FROM   RUN_STATISTICS R, PROG_VER V, TESTS T
WHERE  R.MACHINE = 'bach' AND V.MACHINE = R.MACHINE
AND    R.PROG = V.PROG AND R.VER = V.VER
AND    V.STATUS = 'C'
AND    R.BENCH_ID = T.BENCH_ID AND R.PROG = T.PROG
ORDER BY T.BENCHMARK, T.PROG, T.OPTIONS, T.INPUT_NO, R.BENCH_ID;

-- ============================================================================
-- Benchmark Results on Machine "dbs1":
-- ============================================================================

CREATE VIEW DBS_RESULTS AS
SELECT R.BENCH_ID AS BENCH,
	R.PROG AS PROG,
	R.AVG_LOAD_TIME AS LOAD_S,
	R.AVG_EXEC_TIME AS EXEC_S,
	R.AVG_TOTAL_TIME AS TOTAL_S,
	R.AVG_REAL_TIME AS REAL_S,
	R.AVG_MEM AS MEM_MB
FROM   RUN_STATISTICS R, PROG_VER V, TESTS T
WHERE  R.MACHINE = 'dbs1' AND V.MACHINE = R.MACHINE
AND    R.PROG = V.PROG AND R.VER = V.VER
AND    V.STATUS = 'C'
AND    R.BENCH_ID = T.BENCH_ID AND R.PROG = T.PROG
ORDER BY T.BENCHMARK, T.PROG, T.OPTIONS, T.INPUT_NO, R.BENCH_ID;

